@@ -17,79 +17,122 @@
 #include "auxiliary/kspaths.h"
 #include "offlineastrometryparser.h"
 #include "align.h"
+#include "ksutils.h"
 
 namespace Ekos
 {
-
 OfflineAstrometryParser::OfflineAstrometryParser() : AstrometryParser()
 {
-    astrometryIndex[2.8] = "index-4200";
-    astrometryIndex[4.0] = "index-4201";
-    astrometryIndex[5.6] = "index-4202";
-    astrometryIndex[8] = "index-4203";
-    astrometryIndex[11] = "index-4204";
-    astrometryIndex[16] = "index-4205";
-    astrometryIndex[22] = "index-4206";
-    astrometryIndex[30] = "index-4207";
-    astrometryIndex[42] = "index-4208";
-    astrometryIndex[60] = "index-4209";
-    astrometryIndex[85] = "index-4210";
-    astrometryIndex[120] = "index-4211";
-    astrometryIndex[170] = "index-4212";
-    astrometryIndex[240] = "index-4213";
-    astrometryIndex[340] = "index-4214";
-    astrometryIndex[480] = "index-4215";
-    astrometryIndex[680] = "index-4216";
+    astrometryIndex[2.8]  = "index-4200";
+    astrometryIndex[4.0]  = "index-4201";
+    astrometryIndex[5.6]  = "index-4202";
+    astrometryIndex[8]    = "index-4203";
+    astrometryIndex[11]   = "index-4204";
+    astrometryIndex[16]   = "index-4205";
+    astrometryIndex[22]   = "index-4206";
+    astrometryIndex[30]   = "index-4207";
+    astrometryIndex[42]   = "index-4208";
+    astrometryIndex[60]   = "index-4209";
+    astrometryIndex[85]   = "index-4210";
+    astrometryIndex[120]  = "index-4211";
+    astrometryIndex[170]  = "index-4212";
+    astrometryIndex[240]  = "index-4213";
+    astrometryIndex[340]  = "index-4214";
+    astrometryIndex[480]  = "index-4215";
+    astrometryIndex[680]  = "index-4216";
     astrometryIndex[1000] = "index-4217";
     astrometryIndex[1400] = "index-4218";
     astrometryIndex[2000] = "index-4219";
 
     astrometryFilesOK = false;
-
 }
 
 OfflineAstrometryParser::~OfflineAstrometryParser()
 {
-
 }
 
 bool OfflineAstrometryParser::init()
 {
+#ifdef Q_OS_OSX
+    if (Options::astrometryConfFileIsInternal())
+        KSUtils::configureDefaultAstrometry();
+#endif
+
     if (astrometryFilesOK)
         return true;
 
     if (astrometryNetOK() == false)
     {
         if (align && align->isEnabled())
-            KMessageBox::information(NULL, i18n("Failed to find astrometry.net binaries. Please ensure astrometry.net is installed and try again."),
-                                 i18n("Missing astrometry files"), "missing_astrometry_binaries_warning");
+            KMessageBox::information(
+                nullptr,
+                i18n(
+                    "Failed to find astrometry.net binaries. Please ensure astrometry.net is installed and try again."),
+                i18n("Missing astrometry files"), "missing_astrometry_binaries_warning");
 
         return false;
     }
 
     astrometryFilesOK = true;
+
+    QProcess solveField;
+#ifdef Q_OS_OSX
+    // Please check if this works!
+    solveField.start("bash", QStringList() << "-c"
+                                           << "solve-field | grep Revision");
+#else
+    solveField.start("bash", QStringList() << "-c"
+                                           << "solve-field | grep Revision");
+#endif
+    solveField.waitForFinished();
+    QString output = solveField.readAllStandardOutput();
+    qDebug() << output;
+
+    if (output.isEmpty() == false)
+    {
+        QString version = output.mid(9, 4);
+
+        align->appendLogText(i18n("Detected Astrometry.net version %1", version));
+
+        if (version <= "0.67" && Options::astrometryUseNoFITS2FITS() == false)
+        {
+            Options::setAstrometryUseNoFITS2FITS(true);
+            align->appendLogText(i18n("Setting astrometry option --no-fits2fits"));
+        }
+        else if (version > "0.67" && Options::astrometryUseNoFITS2FITS())
+        {
+            Options::setAstrometryUseNoFITS2FITS(false);
+            align->appendLogText(i18n("Turning off option --no-fits2fits"));
+        }
+    }
+
     return true;
 }
 
 bool OfflineAstrometryParser::astrometryNetOK()
 {
-    bool solverOK=false, wcsinfoOK=false;
+    bool solverOK = false, wcsinfoOK = false;
 
-    if(Options::astrometrySolverIsInternal()){
-        QFileInfo solver(QCoreApplication::applicationDirPath()+"/astrometry/bin/solve-field");
+    if (Options::astrometrySolverIsInternal())
+    {
+        QFileInfo solver(QCoreApplication::applicationDirPath() + "/astrometry/bin/solve-field");
         solverOK = solver.exists() && solver.isFile();
     }
-    else{
-        QFileInfo solver(Options::astrometrySolver());
+    else
+    {
+        QFileInfo solver(Options::astrometrySolverBinary());
         solverOK = solver.exists() && solver.isFile();
     }
 
-    if(Options::wcsIsInternal()){
-        QFileInfo wcsinfo(QCoreApplication::applicationDirPath()+"/astrometry/bin/wcsinfo");
-        wcsinfoOK  = wcsinfo.exists() && wcsinfo.isFile();
-    }else{
+    if (Options::astrometryWCSIsInternal())
+    {
+        QFileInfo wcsinfo(QCoreApplication::applicationDirPath() + "/astrometry/bin/wcsinfo");
+        wcsinfoOK = wcsinfo.exists() && wcsinfo.isFile();
+    }
+    else
+    {
         QFileInfo wcsinfo(Options::astrometryWCSInfo());
-        wcsinfoOK  = wcsinfo.exists() && wcsinfo.isFile();
+        wcsinfoOK = wcsinfo.exists() && wcsinfo.isFile();
     }
 
     return (solverOK && wcsinfoOK);
@@ -97,13 +140,13 @@ bool OfflineAstrometryParser::astrometryNetOK()
 
 void OfflineAstrometryParser::verifyIndexFiles(double fov_x, double fov_y)
 {
-    static double last_fov_x=0, last_fov_y=0;
+    static double last_fov_x = 0, last_fov_y = 0;
 
     if (last_fov_x == fov_x && last_fov_y == fov_y)
         return;
 
-    last_fov_x = fov_x;
-    last_fov_y = fov_y;
+    last_fov_x       = fov_x;
+    last_fov_y       = fov_y;
     double fov_lower = 0.10 * fov_x;
     double fov_upper = fov_x;
     QStringList indexFiles;
@@ -116,11 +159,11 @@ void OfflineAstrometryParser::verifyIndexFiles(double fov_x, double fov_y)
     QStringList nameFilter("*.fits");
     QDir directory(astrometryDataDir);
     QStringList indexList = directory.entryList(nameFilter);
-    QString indexSearch = indexList.join(" ");
+    QString indexSearch   = indexList.join(" ");
     QString startIndex, lastIndex;
-    unsigned int missingIndexes=0;
+    unsigned int missingIndexes = 0;
 
-    foreach(float skymarksize, astrometryIndex.keys())
+    foreach (float skymarksize, astrometryIndex.keys())
     {
         if (skymarksize >= fov_lower && skymarksize <= fov_upper)
         {
@@ -137,19 +180,21 @@ void OfflineAstrometryParser::verifyIndexFiles(double fov_x, double fov_y)
 
                 missingIndexes++;
             }
-
         }
     }
 
     if (indexesOK == false)
     {
         if (missingIndexes == 1)
-            align->appendLogText(i18n("Index file %1 is missing. Astrometry.net would not be able to adequately solve plates until you install the missing index files. Download the index files from http://www.astrometry.net",
-                                             startIndex));
+            align->appendLogText(
+                i18n("Index file %1 is missing. Astrometry.net would not be able to adequately solve plates until you "
+                     "install the missing index files. Download the index files from http://www.astrometry.net",
+                     startIndex));
         else
-            align->appendLogText(i18n("Index files %1 to %2 are missing. Astrometry.net would not be able to adequately solve plates until you install the missing index files. Download the index files from http://www.astrometry.net",
-                                             startIndex, lastIndex));
-
+            align->appendLogText(i18n("Index files %1 to %2 are missing. Astrometry.net would not be able to "
+                                      "adequately solve plates until you install the missing index files. Download the "
+                                      "index files from http://www.astrometry.net",
+                                      startIndex, lastIndex));
     }
 }
 
@@ -157,8 +202,8 @@ bool OfflineAstrometryParser::getAstrometryDataDir(QString &dataDir)
 {
     QString confPath;
 
-    if(Options::astrometryConfFileIsInternal())
-        confPath = QCoreApplication::applicationDirPath()+"/astrometry/bin/astrometry.cfg";
+    if (Options::astrometryConfFileIsInternal())
+        confPath = QCoreApplication::applicationDirPath() + "/astrometry/bin/astrometry.cfg";
     else
         confPath = Options::astrometryConfFile();
 
@@ -166,47 +211,59 @@ bool OfflineAstrometryParser::getAstrometryDataDir(QString &dataDir)
 
     if (confFile.open(QIODevice::ReadOnly) == false)
     {
-        KMessageBox::error(0, i18n("Astrometry configuration file corrupted or missing: %1\nPlease set the configuration file full path in INDI options.", Options::astrometryConfFile()));
+        KMessageBox::error(0, i18n("Astrometry configuration file corrupted or missing: %1\nPlease set the "
+                                   "configuration file full path in INDI options.",
+                                   Options::astrometryConfFile()));
         return false;
     }
 
     QTextStream in(&confFile);
     QString line;
-    while ( !in.atEnd() )
+    while (!in.atEnd())
     {
-      line = in.readLine();
-      if (line.isEmpty() || line.startsWith("#"))
-          continue;
+        line = in.readLine();
+        if (line.isEmpty() || line.startsWith("#"))
+            continue;
 
-      line = line.trimmed();
-      if (line.startsWith("add_path"))
-      {
-          dataDir = line.mid(9).trimmed();
-          return true;
-      }
-   }
+        line = line.trimmed();
+        if (line.startsWith("add_path"))
+        {
+            dataDir = line.mid(9).trimmed();
+            return true;
+        }
+    }
 
     KMessageBox::error(0, i18n("Unable to find data dir in astrometry configuration file."));
     return false;
 }
 
-bool OfflineAstrometryParser::startSovler(const QString &filename,  const QStringList &args, bool generated)
+bool OfflineAstrometryParser::startSovler(const QString &filename, const QStringList &args, bool generated)
 {
     INDI_UNUSED(generated);
 
-    #ifdef Q_OS_OSX
+#ifdef Q_OS_OSX
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-    QStringList envlist = env.toStringList();
-    envlist.replaceInStrings(QRegularExpression("^(?i)PATH=(.*)"), "PATH=/usr/local/bin:\\1");
-    solver.setEnvironment(envlist);
-    #endif
+    QString path            = env.value("PATH", "");
+    env.insert("PATH", "/usr/local/bin:" + path);
+    solver.setProcessEnvironment(env);
+#endif
 
     QStringList solverArgs = args;
-    // Add parity option if none is give and we already know parity before
-    if (parity.isEmpty() == false && args.contains("parity") == false)
+
+    // Use parity if it is: 1. Already known from previous solve. 2. This is NOT a blind solve
+    if (Options::astrometryDetectParity() && (parity.isEmpty() == false) && (args.contains("parity") == false) &&
+        (args.contains("-3") || args.contains("-L")))
         solverArgs << "--parity" << parity;
+
+    QString confPath;
+    if (Options::astrometryConfFileIsInternal())
+        confPath = QCoreApplication::applicationDirPath() + "/astrometry/bin/astrometry.cfg";
+    else
+        confPath = Options::astrometryConfFile();
+    solverArgs << "--config" << confPath;
+
     QString solutionFile = QDir::tempPath() + "/solution.wcs";
-    solverArgs << "-W" <<  solutionFile << filename;
+    solverArgs << "-W" << solutionFile << filename;
 
     fitsFile = filename;
 
@@ -214,11 +271,10 @@ bool OfflineAstrometryParser::startSovler(const QString &filename,  const QStrin
     connect(&solver, SIGNAL(readyReadStandardOutput()), this, SLOT(logSolver()));
 
     // Reset parity on solver failure
-    connect(this, &OfflineAstrometryParser::solverFailed, this, [&]() { parity = QString();});
+    connect(this, &OfflineAstrometryParser::solverFailed, this, [&]() { parity = QString(); });
 
-#if QT_VERSION > QT_VERSION_CHECK(5,6,0)
-    connect(&solver, &QProcess::errorOccurred, this, [&]()
-    {
+#if QT_VERSION > QT_VERSION_CHECK(5, 6, 0)
+    connect(&solver, &QProcess::errorOccurred, this, [&]() {
         align->appendLogText(i18n("Error starting solver: %1", solver.errorString()));
         emit solverFailed();
     });
@@ -230,16 +286,16 @@ bool OfflineAstrometryParser::startSovler(const QString &filename,  const QStrin
 
     QString solverPath;
 
-    if(Options::astrometrySolverIsInternal())
-        solverPath=QCoreApplication::applicationDirPath()+"/astrometry/bin/solve-field";
+    if (Options::astrometrySolverIsInternal())
+        solverPath = QCoreApplication::applicationDirPath() + "/astrometry/bin/solve-field";
     else
-        solverPath=Options::astrometrySolver();
+        solverPath = Options::astrometrySolverBinary();
 
     solver.start(solverPath, solverArgs);
 
     align->appendLogText(i18n("Starting solver..."));
 
-    if (Options::solverVerbose())
+    if (Options::astrometrySolverVerbose())
     {
         QString command = solverPath + " " + solverArgs.join(" ");
         align->appendLogText(command);
@@ -276,8 +332,8 @@ void OfflineAstrometryParser::solverComplete(int exist_status)
 
     QString wcsPath;
 
-    if(Options::wcsIsInternal())
-        wcsPath = QCoreApplication::applicationDirPath()+"/astrometry/bin/wcsinfo";
+    if (Options::astrometryWCSIsInternal())
+        wcsPath = QCoreApplication::applicationDirPath() + "/astrometry/bin/wcsinfo";
     else
         wcsPath = Options::astrometryWCSInfo();
 
@@ -286,7 +342,6 @@ void OfflineAstrometryParser::solverComplete(int exist_status)
 
 void OfflineAstrometryParser::wcsinfoComplete(int exist_status)
 {
-
     wcsinfo.disconnect();
 
     if (exist_status != 0)
@@ -302,9 +357,9 @@ void OfflineAstrometryParser::wcsinfoComplete(int exist_status)
 
     QStringList key_value;
 
-    double ra=0, dec=0, orientation=0, pixscale=0;    
+    double ra = 0, dec = 0, orientation = 0, pixscale = 0;
 
-    foreach(QString key, wcskeys)
+    foreach (QString key, wcskeys)
     {
         key_value = key.split(" ");
 
@@ -323,28 +378,15 @@ void OfflineAstrometryParser::wcsinfoComplete(int exist_status)
         }
     }
 
-    int elapsed = (int) round(solverTimer.elapsed()/1000.0);
+    int elapsed = (int)round(solverTimer.elapsed() / 1000.0);
     align->appendLogText(i18np("Solver completed in %1 second.", "Solver completed in %1 seconds.", elapsed));
 
-    emit solverFinished(orientation,ra,dec, pixscale);
-
-    // Remove files left over by the solver
-    //QDir dir("/tmp");
-    QDir dir(QDir::tempPath());
-    dir.setNameFilters(QStringList() << "fits*" << "tmp.*");
-    dir.setFilter(QDir::Files);
-    foreach(QString dirFile, dir.entryList())
-            dir.remove(dirFile);
-
+    emit solverFinished(orientation, ra, dec, pixscale);
 }
 
 void OfflineAstrometryParser::logSolver()
 {
-    if (Options::solverVerbose())
+    if (Options::astrometrySolverVerbose())
         align->appendLogText(solver.readAll().trimmed());
 }
-
 }
-
-
-
