@@ -62,32 +62,33 @@
 #include "indi/indilistener.h"
 #endif
 
-#define INITIAL_W	785
-#define INITIAL_H	650
+#define INITIAL_W 785
+#define INITIAL_H 650
 
-QStringList FITSViewer::filterTypes = QStringList() << I18N_NOOP("Auto Stretch") << I18N_NOOP("High Contrast")
-                                                    << I18N_NOOP("Equalize") << I18N_NOOP("High Pass") << I18N_NOOP("Median")
-                                                    << I18N_NOOP("Rotate Right") << I18N_NOOP("Rotate Left")
-                                                    << I18N_NOOP("Flip Horizontal") << I18N_NOOP("Flip Vertical");
+QStringList FITSViewer::filterTypes =
+    QStringList() << I18N_NOOP("Auto Stretch") << I18N_NOOP("High Contrast") << I18N_NOOP("Equalize")
+                  << I18N_NOOP("High Pass") << I18N_NOOP("Median") << I18N_NOOP("Rotate Right")
+                  << I18N_NOOP("Rotate Left") << I18N_NOOP("Flip Horizontal") << I18N_NOOP("Flip Vertical");
 
-FITSViewer::FITSViewer (QWidget *parent)
-        : KXmlGuiWindow (parent)
+FITSViewer::FITSViewer(QWidget *parent) : KXmlGuiWindow(parent)
 {
 #ifdef Q_OS_OSX
-    if(Options::independentWindowFITS())
-         setWindowFlags(Qt::Window);
-     else{
+    if (Options::independentWindowFITS())
+        setWindowFlags(Qt::Window);
+    else
+    {
         setWindowFlags(Qt::Window | Qt::WindowStaysOnTopHint);
-        connect(QApplication::instance(), SIGNAL(applicationStateChanged(Qt::ApplicationState)), this, SLOT(changeAlwaysOnTop(Qt::ApplicationState)));
-     }
+        connect(QApplication::instance(), SIGNAL(applicationStateChanged(Qt::ApplicationState)), this,
+                SLOT(changeAlwaysOnTop(Qt::ApplicationState)));
+    }
 #endif
 
     fitsTab   = new QTabWidget(this);
     undoGroup = new QUndoGroup(this);
 
-    fitsID = 0;
-    debayerDialog= NULL;
-    markStars = false;
+    fitsID        = 0;
+    debayerDialog = nullptr;
+    markStars     = false;
 
     lastURL = QUrl(QDir::homePath());
 
@@ -100,13 +101,13 @@ FITSViewer::FITSViewer (QWidget *parent)
     connect(fitsTab, SIGNAL(currentChanged(int)), this, SLOT(tabFocusUpdated(int)));
     connect(fitsTab, SIGNAL(tabCloseRequested(int)), this, SLOT(closeTab(int)));
 
-    //These two connections will enable or disable the scope button if a scope is available or not.
-    //Of course this is also dependent on the presence of WCS data in the image.
+//These two connections will enable or disable the scope button if a scope is available or not.
+//Of course this is also dependent on the presence of WCS data in the image.
 
-    #ifdef HAVE_INDI
+#ifdef HAVE_INDI
     connect(INDIListener::Instance(), SIGNAL(newTelescope(ISD::GDInterface *)), this, SLOT(updateWCSFunctions()));
     connect(INDIListener::Instance(), SIGNAL(deviceRemoved(ISD::GDInterface *)), this, SLOT(updateWCSFunctions()));
-    #endif
+#endif
 
     led.setColor(Qt::green);
 
@@ -136,7 +137,8 @@ FITSViewer::FITSViewer (QWidget *parent)
 
     action = actionCollection()->addAction("flip_horizontal", this, SLOT(flipHorizontal()));
     action->setText(i18n("Flip Horizontal"));
-    action->setIcon(QIcon::fromTheme("object-flip-horizontal", QIcon(":/icons/breeze/default/object-flip-horizontal.svg")));
+    action->setIcon(
+        QIcon::fromTheme("object-flip-horizontal", QIcon(":/icons/breeze/default/object-flip-horizontal.svg")));
 
     action = actionCollection()->addAction("flip_vertical", this, SLOT(flipVertical()));
     action->setText(i18n("Flip Vertical"));
@@ -144,56 +146,57 @@ FITSViewer::FITSViewer (QWidget *parent)
 
     action = actionCollection()->addAction("image_histogram");
     action->setText(i18n("Histogram"));
-    connect(action, SIGNAL(triggered(bool)), SLOT (histoFITS()));
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL+Qt::Key_T));
+    connect(action, SIGNAL(triggered(bool)), SLOT(histoFITS()));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_T));
 
     action->setIcon(QIcon(":/icons/histogram.png"));
 
-    action = KStandardAction::open(this,   SLOT(openFile()),   actionCollection());
+    action = KStandardAction::open(this, SLOT(openFile()), actionCollection());
     action->setIcon(QIcon::fromTheme("document-open", QIcon(":/icons/breeze/default/document-open.svg")));
-    
-    saveFileAction    = KStandardAction::save(this,   SLOT(saveFile()),   actionCollection());
+
+    saveFileAction = KStandardAction::save(this, SLOT(saveFile()), actionCollection());
     saveFileAction->setIcon(QIcon::fromTheme("document-save", QIcon(":/icons/breeze/default/document-save.svg")));
 
-    action=saveFileAsAction  = KStandardAction::saveAs(this, SLOT(saveFileAs()), actionCollection());
-    saveFileAsAction->setIcon(QIcon::fromTheme("document-save_as", QIcon(":/icons/breeze/default/document-save-as.svg")));
+    action = saveFileAsAction = KStandardAction::saveAs(this, SLOT(saveFileAs()), actionCollection());
+    saveFileAsAction->setIcon(
+        QIcon::fromTheme("document-save_as", QIcon(":/icons/breeze/default/document-save-as.svg")));
 
     action = actionCollection()->addAction("fits_header");
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL+Qt::Key_H));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_H));
     action->setIcon(QIcon::fromTheme("document-properties", QIcon(":/icons/breeze/default/document-properties.svg")));
-    action->setText(i18n( "FITS Header"));
-    connect(action, SIGNAL(triggered(bool) ), SLOT(headerFITS()));
+    action->setText(i18n("FITS Header"));
+    connect(action, SIGNAL(triggered(bool)), SLOT(headerFITS()));
 
     action = actionCollection()->addAction("fits_debayer");
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL+Qt::Key_D));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_D));
     action->setIcon(QIcon::fromTheme("view-preview", QIcon(":/icons/breeze/default/view-preview.svg")));
-    action->setText(i18n( "Debayer..."));
-    connect(action, SIGNAL(triggered(bool) ), SLOT(debayerFITS()));
+    action->setText(i18n("Debayer..."));
+    connect(action, SIGNAL(triggered(bool)), SLOT(debayerFITS()));
 
     action = actionCollection()->addAction("image_stretch");
     action->setText(i18n("Auto stretch"));
-    connect(action, SIGNAL(triggered(bool)), SLOT (stretchFITS()));
+    connect(action, SIGNAL(triggered(bool)), SLOT(stretchFITS()));
     actionCollection()->setDefaultShortcut(action, QKeySequence::SelectAll);
     action->setIcon(QIcon::fromTheme("transform-move", QIcon(":/icons/breeze/default/transform-move.svg")));
 
-    action = KStandardAction::close(this,  SLOT(close()),  actionCollection());
+    action = KStandardAction::close(this, SLOT(close()), actionCollection());
     action->setIcon(QIcon::fromTheme("window-close", QIcon(":/icons/breeze/default/window-close.svg")));
-    
-    action = KStandardAction::copy(this,   SLOT(copyFITS()),   actionCollection());
+
+    action = KStandardAction::copy(this, SLOT(copyFITS()), actionCollection());
     action->setIcon(QIcon::fromTheme("edit-copy", QIcon(":/icons/breeze/default/edit-copy.svg")));
-    
-    action=KStandardAction::zoomIn(this,     SLOT(ZoomIn()),      actionCollection());
+
+    action = KStandardAction::zoomIn(this, SLOT(ZoomIn()), actionCollection());
     action->setIcon(QIcon::fromTheme("zoom-in", QIcon(":/icons/breeze/default/zoom-in.svg")));
-    
-    action=KStandardAction::zoomOut(this,    SLOT(ZoomOut()),     actionCollection());
+
+    action = KStandardAction::zoomOut(this, SLOT(ZoomOut()), actionCollection());
     action->setIcon(QIcon::fromTheme("zoom-out", QIcon(":/icons/breeze/default/zoom-out.svg")));
-    
-    action=KStandardAction::actualSize(this, SLOT(ZoomDefault()), actionCollection());
+
+    action = KStandardAction::actualSize(this, SLOT(ZoomDefault()), actionCollection());
     action->setIcon(QIcon::fromTheme("zoom-fit-best", QIcon(":/icons/breeze/default/zoom-fit-best.svg")));
 
     QAction *kundo = KStandardAction::undo(undoGroup, SLOT(undo()), actionCollection());
     kundo->setIcon(QIcon::fromTheme("edit-undo", QIcon(":/icons/breeze/default/edit-undo.svg")));
-    
+
     QAction *kredo = KStandardAction::redo(undoGroup, SLOT(redo()), actionCollection());
     kredo->setIcon(QIcon::fromTheme("edit-redo", QIcon(":/icons/breeze/default/edit-redo.svg")));
 
@@ -202,64 +205,61 @@ FITSViewer::FITSViewer (QWidget *parent)
 
     action = actionCollection()->addAction("image_stats");
     action->setIcon(QIcon::fromTheme("view-statistics", QIcon(":/icons/breeze/default/view-statistics.svg")));
-    action->setText(i18n( "Statistics"));
+    action->setText(i18n("Statistics"));
     connect(action, SIGNAL(triggered(bool)), SLOT(statFITS()));
 
     action = actionCollection()->addAction("view_crosshair");
     action->setIcon(QIcon::fromTheme("crosshairs", QIcon(":/icons/breeze/default/crosshairs.svg")));
-    action->setText(i18n( "Show Cross Hairs"));
+    action->setText(i18n("Show Cross Hairs"));
     action->setCheckable(true);
     connect(action, SIGNAL(triggered(bool)), SLOT(toggleCrossHair()));
 
     action = actionCollection()->addAction("view_pixel_grid");
     action->setIcon(QIcon::fromTheme("map-flat", QIcon(":/icons/breeze/default/map-flat.svg")));
-    action->setText(i18n( "Show Pixel Gridlines"));
+    action->setText(i18n("Show Pixel Gridlines"));
     action->setCheckable(true);
     connect(action, SIGNAL(triggered(bool)), SLOT(togglePixelGrid()));
 
     action = actionCollection()->addAction("view_eq_grid");
     action->setIcon(QIcon::fromTheme("kstars_grid", QIcon(":/icons/breeze/default/kstars_grid.svg")));
-    action->setText(i18n( "Show Equatorial Gridlines"));
+    action->setText(i18n("Show Equatorial Gridlines"));
     action->setCheckable(true);
     action->setDisabled(true);
     connect(action, SIGNAL(triggered(bool)), SLOT(toggleEQGrid()));
 
     action = actionCollection()->addAction("view_objects");
     action->setIcon(QIcon::fromTheme("help-hint", QIcon(":/icons/breeze/default/help-hint.svg")));
-    action->setText(i18n( "Show Objects in Image"));
+    action->setText(i18n("Show Objects in Image"));
     action->setCheckable(true);
     action->setDisabled(true);
     connect(action, SIGNAL(triggered(bool)), SLOT(toggleObjects()));
 
     action = actionCollection()->addAction("center_telescope");
     action->setIcon(QIcon(":/icons/center_telescope.svg"));
-    action->setText(i18n( "Center Telescope\n*No Telescopes Detected*"));
+    action->setText(i18n("Center Telescope\n*No Telescopes Detected*"));
     action->setDisabled(true);
     action->setCheckable(true);
     connect(action, SIGNAL(triggered(bool)), SLOT(centerTelescope()));
 
     action = actionCollection()->addAction("view_zoom_fit");
     action->setIcon(QIcon::fromTheme("zoom-fit-width", QIcon(":/icons/breeze/default/zoom-fit-width.svg")));
-    action->setText(i18n( "Zoom To Fit"));
+    action->setText(i18n("Zoom To Fit"));
     connect(action, SIGNAL(triggered(bool)), SLOT(ZoomToFit()));
 
     action = actionCollection()->addAction("mark_stars");
-    action->setText(i18n( "Mark Stars"));
+    action->setText(i18n("Mark Stars"));
     connect(action, SIGNAL(triggered(bool)), SLOT(toggleStars()));
 
     QSignalMapper *filterMapper = new QSignalMapper(this);
 
-    int filterCounter=1;
+    int filterCounter = 1;
 
-    foreach(QString filter, FITSViewer::filterTypes)
+    foreach (QString filter, FITSViewer::filterTypes)
     {
-
         action = actionCollection()->addAction(QString("filter%1").arg(filterCounter));
         action->setText(i18n(filter.toUtf8().constData()));
         filterMapper->setMapping(action, filterCounter++);
         connect(action, SIGNAL(triggered()), filterMapper, SLOT(map()));
-
-
     }
 
     connect(filterMapper, SIGNAL(mapped(int)), this, SLOT(applyFilter(int)));
@@ -275,7 +275,8 @@ FITSViewer::FITSViewer (QWidget *parent)
 
 void FITSViewer::changeAlwaysOnTop(Qt::ApplicationState state)
 {
-    if(isVisible()){
+    if (isVisible())
+    {
         if (state == Qt::ApplicationActive)
             setWindowFlags(Qt::Window | Qt::WindowStaysOnTopHint);
         else
@@ -294,14 +295,13 @@ FITSViewer::~FITSViewer()
     qDeleteAll(fitsTabs);
 }
 
-
 void FITSViewer::closeEvent(QCloseEvent * /*event*/)
 {
     KStars *ks = KStars::Instance();
 
     if (ks)
     {
-        QAction *a = KStars::Instance()->actionCollection()->action( "show_fits_viewer" );
+        QAction *a                  = KStars::Instance()->actionCollection()->action("show_fits_viewer");
         QList<FITSViewer *> viewers = KStars::Instance()->findChildren<FITSViewer *>();
 
         if (a && viewers.count() == 1)
@@ -318,7 +318,7 @@ void FITSViewer::hideEvent(QHideEvent * /*event*/)
 
     if (ks)
     {
-        QAction *a = KStars::Instance()->actionCollection()->action( "show_fits_viewer" );
+        QAction *a = KStars::Instance()->actionCollection()->action("show_fits_viewer");
         if (a)
         {
             QList<FITSViewer *> viewers = KStars::Instance()->findChildren<FITSViewer *>();
@@ -331,7 +331,7 @@ void FITSViewer::hideEvent(QHideEvent * /*event*/)
 
 void FITSViewer::showEvent(QShowEvent * /*event*/)
 {
-    QAction *a = KStars::Instance()->actionCollection()->action( "show_fits_viewer" );
+    QAction *a = KStars::Instance()->actionCollection()->action("show_fits_viewer");
     if (a)
     {
         a->setEnabled(true);
@@ -346,13 +346,12 @@ int FITSViewer::addFITS(const QUrl *imageName, FITSMode mode, FITSScale filter,
     led.setColor(Qt::yellow);
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
-    if (tab->loadFITS(imageName,mode, filter, silent) == false)
+    if (tab->loadFITS(imageName, mode, filter, silent) == false)
     {
         QApplication::restoreOverrideCursor();
         led.setColor(Qt::red);
         if (fitsTabs.size() == 0)
         {
-
             // Close FITS Viewer and let KStars know it is no longer needed in memory.
             close();
             return -2;
@@ -366,37 +365,36 @@ int FITSViewer::addFITS(const QUrl *imageName, FITSMode mode, FITSScale filter,
     QApplication::restoreOverrideCursor();
     tab->setPreviewText(previewText);
 
-    connect(tab, SIGNAL(newStatus(QString,FITSBar)), this, SLOT(updateStatusBar(QString,FITSBar)));
-    connect(tab->getView(), SIGNAL(actionUpdated(QString,bool)), this, SLOT(updateAction(QString,bool)));
+    connect(tab, SIGNAL(newStatus(QString, FITSBar)), this, SLOT(updateStatusBar(QString, FITSBar)));
+    connect(tab->getView(), SIGNAL(actionUpdated(QString, bool)), this, SLOT(updateAction(QString, bool)));
     connect(tab, SIGNAL(changeStatus(bool)), this, SLOT(updateTabStatus(bool)));
     connect(tab, SIGNAL(debayerToggled(bool)), this, SLOT(setDebayerAction(bool)));
     connect(tab->getView(), SIGNAL(wcsToggled(bool)), this, SLOT(updateWCSFunctions()));
 
     switch (mode)
     {
-      case FITS_NORMAL:
-        fitsTab->addTab(tab, previewText.isEmpty() ? imageName->fileName() : previewText);
-        break;
+        case FITS_NORMAL:
+            fitsTab->addTab(tab, previewText.isEmpty() ? imageName->fileName() : previewText);
+            break;
 
-       case FITS_CALIBRATE:
-        fitsTab->addTab(tab, i18n("Calibrate"));
-        break;
+        case FITS_CALIBRATE:
+            fitsTab->addTab(tab, i18n("Calibrate"));
+            break;
 
-      case FITS_FOCUS:
-        fitsTab->addTab(tab, i18n("Focus"));
-        break;
+        case FITS_FOCUS:
+            fitsTab->addTab(tab, i18n("Focus"));
+            break;
 
-    case FITS_GUIDE:
-      fitsTab->addTab(tab, i18n("Guide"));
-      break;
+        case FITS_GUIDE:
+            fitsTab->addTab(tab, i18n("Guide"));
+            break;
 
-    case FITS_ALIGN:
-      fitsTab->addTab(tab, i18n("Align"));
-      break;
-
-    default:
-        break;
+        case FITS_ALIGN:
+            fitsTab->addTab(tab, i18n("Align"));
+            break;
 
+        default:
+            break;
     }
 
     saveFileAction->setEnabled(true);
@@ -430,7 +428,7 @@ bool FITSViewer::removeFITS(int fitsUID)
 {
     FITSTab *tab = fitsMap.value(fitsUID);
 
-    if (tab == NULL)
+    if (tab == nullptr)
     {
         qDebug() << "Cannot find tab with UID " << fitsUID << " in the FITS Viewer";
         return false;
@@ -445,20 +443,19 @@ bool FITSViewer::removeFITS(int fitsUID)
     }
 
     return false;
-
 }
 
 bool FITSViewer::updateFITS(const QUrl *imageName, int fitsUID, FITSScale filter, bool silent)
 {
     FITSTab *tab = fitsMap.value(fitsUID);
 
-    if (tab == NULL)
+    if (tab == nullptr)
     {
         qDebug() << "Cannot find tab with UID " << fitsUID << " in the FITS Viewer";
         return false;
     }
 
-    bool rc=false;
+    bool rc = false;
 
     if (tab->isVisible())
         led.setColor(Qt::yellow);
@@ -472,8 +469,10 @@ bool FITSViewer::updateFITS(const QUrl *imageName, int fitsUID, FITSScale filter
             int tabIndex = fitsTab->indexOf(tab);
             if (tabIndex != -1 && tab->getView()->getMode() == FITS_NORMAL)
             {
-                if ( (imageName->path().startsWith("/tmp") || imageName->path().contains("/Temp")) && Options::singlePreviewFITS())
-                    fitsTab->setTabText(tabIndex, tab->getPreviewText().isEmpty()? i18n("Preview") : tab->getPreviewText());
+                if ((imageName->path().startsWith("/tmp") || imageName->path().contains("/Temp")) &&
+                    Options::singlePreviewFITS())
+                    fitsTab->setTabText(tabIndex,
+                                        tab->getPreviewText().isEmpty() ? i18n("Preview") : tab->getPreviewText());
                 else
                     fitsTab->setTabText(tabIndex, imageName->fileName());
             }
@@ -508,7 +507,8 @@ void FITSViewer::tabFocusUpdated(int currentIndex)
         view->updateFrame();
 
     if (markStars)
-        updateStatusBar(i18np("%1 star detected.", "%1 stars detected.",view->getImageData()->getDetectedStars()), FITS_MESSAGE);
+        updateStatusBar(i18np("%1 star detected.", "%1 stars detected.", view->getImageData()->getDetectedStars()),
+                        FITS_MESSAGE);
     else
         updateStatusBar("", FITS_MESSAGE);
 
@@ -533,8 +533,6 @@ void FITSViewer::tabFocusUpdated(int currentIndex)
     updateButtonStatus("view_pixel_grid", "Pixel Gridines", getCurrentView()->isPixelGridShown());
     updateScopeButton();
     updateWCSFunctions();
-
-
 }
 
 // No need to warn users about unsaved changes in a "viewer".
@@ -575,15 +573,15 @@ void FITSViewer::closeEvent(QCloseEvent *ev)
 
 void FITSViewer::openFile()
 {
-    QUrl fileURL = QFileDialog::getOpenFileUrl(KStars::Instance(), i18n("Open FITS Image"), lastURL, "FITS (*.fits *.fit)");
+    QUrl fileURL =
+        QFileDialog::getOpenFileUrl(KStars::Instance(), i18n("Open FITS Image"), lastURL, "FITS (*.fits *.fit)");
     if (fileURL.isEmpty())
         return;
 
-    lastURL = QUrl(fileURL.url(QUrl::RemoveFilename));
+    lastURL       = QUrl(fileURL.url(QUrl::RemoveFilename));
     QString fpath = fileURL.toLocalFile();
     QString cpath;
 
-
     // Make sure we don't have it open already, if yes, switch to it
     foreach (FITSTab *tab, fitsTabs)
     {
@@ -596,7 +594,6 @@ void FITSViewer::openFile()
     }
 
     addFITS(&fileURL, FITS_NORMAL, FITS_NONE, QString(), false);
-
 }
 
 void FITSViewer::saveFile()
@@ -609,9 +606,9 @@ void FITSViewer::saveFileAs()
     if (fitsTabs.empty())
         return;
 
-    if (fitsTabs[fitsTab->currentIndex()]->saveFileAs() && fitsTabs[fitsTab->currentIndex()]->getView()->getMode() == FITS_NORMAL)
+    if (fitsTabs[fitsTab->currentIndex()]->saveFileAs() &&
+        fitsTabs[fitsTab->currentIndex()]->getView()->getMode() == FITS_NORMAL)
         fitsTab->setTabText(fitsTab->currentIndex(), fitsTabs[fitsTab->currentIndex()]->getCurrentURL()->fileName());
-
 }
 
 void FITSViewer::copyFITS()
@@ -619,7 +616,7 @@ void FITSViewer::copyFITS()
     if (fitsTabs.empty())
         return;
 
-   fitsTabs[fitsTab->currentIndex()]->copyFITS();
+    fitsTabs[fitsTab->currentIndex()]->copyFITS();
 }
 
 void FITSViewer::histoFITS()
@@ -635,7 +632,7 @@ void FITSViewer::statFITS()
     if (fitsTabs.empty())
         return;
 
-  fitsTabs[fitsTab->currentIndex()]->statFITS();
+    fitsTabs[fitsTab->currentIndex()]->statFITS();
 }
 
 void FITSViewer::stretchFITS()
@@ -668,19 +665,19 @@ void FITSViewer::headerFITS()
     if (fitsTabs.empty())
         return;
 
-  fitsTabs[fitsTab->currentIndex()]->headerFITS();
+    fitsTabs[fitsTab->currentIndex()]->headerFITS();
 }
 
 void FITSViewer::debayerFITS()
 {
-    if (debayerDialog == NULL)
+    if (debayerDialog == nullptr)
     {
         debayerDialog = new FITSDebayer(this);
     }
 
     FITSView *view = getCurrentView();
 
-    if (view == NULL)
+    if (view == nullptr)
         return;
 
     BayerParams param;
@@ -688,12 +685,11 @@ void FITSViewer::debayerFITS()
     debayerDialog->setBayerParams(&param);
 
     debayerDialog->show();
-
 }
 
 int FITSViewer::saveUnsaved(int index)
 {
-    FITSTab *targetTab = NULL;
+    FITSTab *targetTab = nullptr;
 
     if (index < 0 || index >= fitsTabs.size())
         return -1;
@@ -705,25 +701,26 @@ int FITSViewer::saveUnsaved(int index)
     if (targetTab->getUndoStack()->isClean())
         return -1;
 
-    QString caption = i18n( "Save Changes to FITS?" );
-    QString message = i18n( "%1 has unsaved changes.  Would you like to save before closing it?", targetTab->getCurrentURL()->fileName());
-    int ans = KMessageBox::warningYesNoCancel( 0, message, caption, KStandardGuiItem::save(), KStandardGuiItem::discard() );
-    if( ans == KMessageBox::Yes )
+    QString caption = i18n("Save Changes to FITS?");
+    QString message = i18n("%1 has unsaved changes.  Would you like to save before closing it?",
+                           targetTab->getCurrentURL()->fileName());
+    int ans =
+        KMessageBox::warningYesNoCancel(0, message, caption, KStandardGuiItem::save(), KStandardGuiItem::discard());
+    if (ans == KMessageBox::Yes)
     {
         targetTab->saveFile();
         return 0;
     }
-    else if( ans == KMessageBox::No )
+    else if (ans == KMessageBox::No)
     {
-       targetTab->getUndoStack()->clear();
-       return 1;
+        targetTab->getUndoStack()->clear();
+        return 1;
     }
-    else if ( ans == KMessageBox::Cancel)
+    else if (ans == KMessageBox::Cancel)
     {
         return 2;
     }
 
-
     return -1;
 }
 
@@ -731,29 +728,28 @@ void FITSViewer::updateStatusBar(const QString &msg, FITSBar id)
 {
     switch (id)
     {
-            case FITS_POSITION:
-                fitsPosition.setText(msg);
-                break;
-            case FITS_RESOLUTION:
-                fitsResolution.setText(msg);
-                break;
-             case FITS_ZOOM:
-                fitsZoom.setText(msg);
-                break;
-             case FITS_WCS:
-                fitsWCS.setVisible(true);
-                fitsWCS.setText(msg);
-                break;
-             case FITS_VALUE:
-                fitsValue.setText(msg);
-                break;
-             case FITS_MESSAGE:
-                statusBar()->showMessage(msg);
-                break;
-
-             default:
-                break;
+        case FITS_POSITION:
+            fitsPosition.setText(msg);
+            break;
+        case FITS_RESOLUTION:
+            fitsResolution.setText(msg);
+            break;
+        case FITS_ZOOM:
+            fitsZoom.setText(msg);
+            break;
+        case FITS_WCS:
+            fitsWCS.setVisible(true);
+            fitsWCS.setText(msg);
+            break;
+        case FITS_VALUE:
+            fitsValue.setText(msg);
+            break;
+        case FITS_MESSAGE:
+            statusBar()->showMessage(msg);
+            break;
 
+        default:
+            break;
     }
 }
 
@@ -762,7 +758,7 @@ void FITSViewer::ZoomIn()
     if (fitsTabs.empty())
         return;
 
-  fitsTabs[fitsTab->currentIndex()]->ZoomIn();
+    fitsTabs[fitsTab->currentIndex()]->ZoomIn();
 }
 
 void FITSViewer::ZoomOut()
@@ -770,7 +766,7 @@ void FITSViewer::ZoomOut()
     if (fitsTabs.empty())
         return;
 
-  fitsTabs[fitsTab->currentIndex()]->ZoomOut();
+    fitsTabs[fitsTab->currentIndex()]->ZoomOut();
 }
 
 void FITSViewer::ZoomDefault()
@@ -778,7 +774,7 @@ void FITSViewer::ZoomDefault()
     if (fitsTabs.empty())
         return;
 
-  fitsTabs[fitsTab->currentIndex()]->ZoomDefault();
+    fitsTabs[fitsTab->currentIndex()]->ZoomDefault();
 }
 
 void FITSViewer::ZoomToFit()
@@ -786,16 +782,16 @@ void FITSViewer::ZoomToFit()
     if (fitsTabs.empty())
         return;
 
-  getCurrentView()->ZoomToFit();
+    getCurrentView()->ZoomToFit();
 }
 
 void FITSViewer::updateAction(const QString &name, bool enable)
 {
-    QAction *toolAction = NULL;
+    QAction *toolAction = nullptr;
 
     toolAction = actionCollection()->action(name);
-    if (toolAction != NULL)
-        toolAction->setEnabled (enable);
+    if (toolAction != nullptr)
+        toolAction->setEnabled(enable);
 }
 
 void FITSViewer::updateTabStatus(bool clean)
@@ -803,14 +799,14 @@ void FITSViewer::updateTabStatus(bool clean)
     if (fitsTabs.empty() || (fitsTab->currentIndex() >= fitsTabs.size()))
         return;
 
-  if (fitsTabs[fitsTab->currentIndex()]->getView()->getMode() != FITS_NORMAL)
-      return;
+    if (fitsTabs[fitsTab->currentIndex()]->getView()->getMode() != FITS_NORMAL)
+        return;
 
-  //QString tabText = fitsImages[fitsTab->currentIndex()]->getCurrentURL()->fileName();
+    //QString tabText = fitsImages[fitsTab->currentIndex()]->getCurrentURL()->fileName();
 
-  QString tabText = fitsTab->tabText(fitsTab->currentIndex());
+    QString tabText = fitsTab->tabText(fitsTab->currentIndex());
 
-  fitsTab->setTabText(fitsTab->currentIndex(), clean ? tabText.remove('*') : tabText + '*');
+    fitsTab->setTabText(fitsTab->currentIndex(), clean ? tabText.remove('*') : tabText + '*');
 }
 
 void FITSViewer::closeTab(int index)
@@ -849,16 +845,17 @@ void FITSViewer::closeTab(int index)
  when one of them gets pushed and also when tabs are switched.
  */
 
-void FITSViewer::updateButtonStatus(QString action, QString item, bool showing){
-    QAction *a=actionCollection()->action(action);
+void FITSViewer::updateButtonStatus(QString action, QString item, bool showing)
+{
+    QAction *a = actionCollection()->action(action);
     if (showing)
     {
-        a->setText( "Hide " + item );
+        a->setText("Hide " + item);
         a->setChecked(true);
     }
     else
     {
-        a->setText( "Show " + item );
+        a->setText("Show " + item);
         a->setChecked(false);
     }
 }
@@ -869,39 +866,46 @@ This is a method that either enables or disables the WCS based features in the C
 
 void FITSViewer::updateWCSFunctions()
 {
-    if (getCurrentView() == NULL)
+    if (getCurrentView() == nullptr)
         return;
 
-    if(getCurrentView()->imageHasWCS()){
+    if (getCurrentView()->imageHasWCS())
+    {
         actionCollection()->action("view_eq_grid")->setDisabled(false);
-        actionCollection()->action("view_eq_grid")->setText( i18n( "Show Equatorial Gridlines" ));
+        actionCollection()->action("view_eq_grid")->setText(i18n("Show Equatorial Gridlines"));
         actionCollection()->action("view_objects")->setDisabled(false);
-        actionCollection()->action("view_objects")->setText( i18n( "Show Objects in Image" ));
-        if(getCurrentView()->isTelescopeActive()){
+        actionCollection()->action("view_objects")->setText(i18n("Show Objects in Image"));
+        if (getCurrentView()->isTelescopeActive())
+        {
             actionCollection()->action("center_telescope")->setDisabled(false);
 
-            actionCollection()->action("center_telescope")->setText( i18n( "Center Telescope\n*Ready*" ));
+            actionCollection()->action("center_telescope")->setText(i18n("Center Telescope\n*Ready*"));
         }
-        else{
+        else
+        {
             actionCollection()->action("center_telescope")->setDisabled(true);
-            actionCollection()->action("center_telescope")->setText( i18n( "Center Telescope\n*No Telescopes Detected*" ));
+            actionCollection()->action("center_telescope")->setText(i18n("Center Telescope\n*No Telescopes Detected*"));
         }
     }
-    else{
+    else
+    {
         actionCollection()->action("view_eq_grid")->setDisabled(true);
-        actionCollection()->action("view_eq_grid")->setText( i18n( "Show Equatorial Gridlines\n*No WCS Info*" ));
+        actionCollection()->action("view_eq_grid")->setText(i18n("Show Equatorial Gridlines\n*No WCS Info*"));
         actionCollection()->action("center_telescope")->setDisabled(true);
-        actionCollection()->action("center_telescope")->setText( i18n( "Center Telescope\n*No WCS Info*" ));
+        actionCollection()->action("center_telescope")->setText(i18n("Center Telescope\n*No WCS Info*"));
         actionCollection()->action("view_objects")->setDisabled(true);
-        actionCollection()->action("view_objects")->setText( i18n( "Show Objects in Image\n*No WCS Info*" ));
+        actionCollection()->action("view_objects")->setText(i18n("Show Objects in Image\n*No WCS Info*"));
     }
-
 }
 
-void FITSViewer::updateScopeButton(){
-    if(getCurrentView()->getMouseMode()==FITSView::scopeMouse){
+void FITSViewer::updateScopeButton()
+{
+    if (getCurrentView()->getMouseMode() == FITSView::scopeMouse)
+    {
         actionCollection()->action("center_telescope")->setChecked(true);
-    } else{
+    }
+    else
+    {
         actionCollection()->action("center_telescope")->setChecked(false);
     }
 }
@@ -911,19 +915,21 @@ void FITSViewer::updateScopeButton(){
  just by clicking the mouse on a spot in the image.
  */
 
-void FITSViewer::centerTelescope(){
+void FITSViewer::centerTelescope()
+{
     getCurrentView()->setScopeButton(actionCollection()->action("center_telescope"));
-    if(getCurrentView()->getMouseMode()==FITSView::scopeMouse){
+    if (getCurrentView()->getMouseMode() == FITSView::scopeMouse)
+    {
         getCurrentView()->setMouseMode(getCurrentView()->lastMouseMode);
-    } else{
-        getCurrentView()->lastMouseMode=getCurrentView()->getMouseMode();
+    }
+    else
+    {
+        getCurrentView()->lastMouseMode = getCurrentView()->getMouseMode();
         getCurrentView()->setMouseMode(FITSView::scopeMouse);
     }
     updateScopeButton();
 }
 
-
-
 void FITSViewer::toggleCrossHair()
 {
     getCurrentView()->toggleCrosshair();
@@ -952,58 +958,55 @@ void FITSViewer::toggleStars()
     if (markStars)
     {
         markStars = false;
-        actionCollection()->action("mark_stars")->setText( i18n( "Mark Stars" ) );
+        actionCollection()->action("mark_stars")->setText(i18n("Mark Stars"));
     }
     else
     {
         markStars = true;
-        actionCollection()->action("mark_stars")->setText( i18n( "Unmark Stars" ) );
+        actionCollection()->action("mark_stars")->setText(i18n("Unmark Stars"));
     }
 
-    foreach(FITSTab *tab, fitsTabs)
+    foreach (FITSTab *tab, fitsTabs)
     {
         tab->getView()->toggleStars(markStars);
         tab->getView()->updateFrame();
     }
-
 }
 
 void FITSViewer::applyFilter(int ftype)
 {
-
     if (fitsTabs.empty())
         return;
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
-    updateStatusBar(i18n("Processing %1...", filterTypes[ftype-1]), FITS_MESSAGE);
+    updateStatusBar(i18n("Processing %1...", filterTypes[ftype - 1]), FITS_MESSAGE);
     qApp->processEvents();
-    fitsTabs[fitsTab->currentIndex()]->getHistogram()->applyFilter((FITSScale) ftype);
+    fitsTabs[fitsTab->currentIndex()]->getHistogram()->applyFilter((FITSScale)ftype);
     qApp->processEvents();
     fitsTabs[fitsTab->currentIndex()]->getView()->updateFrame();
     QApplication::restoreOverrideCursor();
     updateStatusBar(i18n("Ready."), FITS_MESSAGE);
 }
 
-FITSView * FITSViewer::getView(int fitsUID)
+FITSView *FITSViewer::getView(int fitsUID)
 {
     FITSTab *tab = fitsMap.value(fitsUID);
 
     if (tab)
         return tab->getView();
-    else
-        return NULL;
+
+    return nullptr;
 }
 
 FITSView *FITSViewer::getCurrentView()
 {
-    if (fitsTabs.empty() || fitsTab->currentIndex() >= fitsTabs.count() )
-        return NULL;
+    if (fitsTabs.empty() || fitsTab->currentIndex() >= fitsTabs.count())
+        return nullptr;
 
-     return fitsTabs[fitsTab->currentIndex()]->getView();
+    return fitsTabs[fitsTab->currentIndex()]->getView();
 }
 
 void FITSViewer::setDebayerAction(bool enable)
 {
     actionCollection()->addAction("fits_debayer")->setEnabled(enable);
 }
-
