@@ -8,21 +8,21 @@
 
  */
 
-#ifndef DriverManager_H_
-#define DriverManager_H_
+#pragma once
+
+#include "indicommon.h"
+#include "indidbus.h"
+#include "ui_drivermanager.h"
 
-#include <QFrame>
-#include <QHash>
-#include <QStringList>
 #include <QDialog>
+#include <QFrame>
+#include <QIcon>
+#include <QString>
 
 #include <lilxml.h>
-#include "ui_drivermanager.h"
-#include "indidbus.h"
-#include "indicommon.h"
 
+class QStringList;
 class QTreeWidgetItem;
-class QIcon;
 
 class DriverManager;
 class ServerManager;
@@ -33,8 +33,8 @@ class DriverManagerUI : public QFrame, public Ui::DriverManager
 {
     Q_OBJECT
 
-public:
-    DriverManagerUI(QWidget *parent=0);
+  public:
+    DriverManagerUI(QWidget *parent = 0);
 
     QIcon runningPix;
     QIcon stopPix;
@@ -43,9 +43,8 @@ public:
     QIcon localMode;
     QIcon serverMode;
 
-public slots:
-    void makePortEditable(QTreeWidgetItem* selectedItem, int column);
-
+  public slots:
+    void makePortEditable(QTreeWidgetItem *selectedItem, int column);
 };
 
 /**
@@ -64,21 +63,30 @@ public slots:
  */
 class DriverManager : public QDialog
 {
-
     Q_OBJECT
 
-public:
-
+  public:
     static DriverManager *Instance();
 
-    enum { LOCAL_NAME_COLUMN=0, LOCAL_STATUS_COLUMN, LOCAL_MODE_COLUMN, LOCAL_VERSION_COLUMN, LOCAL_PORT_COLUMN };
-    enum { HOST_STATUS_COLUMN=0, HOST_NAME_COLUMN, HOST_PORT_COLUMN };
-
+    enum
+    {
+        LOCAL_NAME_COLUMN = 0,
+        LOCAL_STATUS_COLUMN,
+        LOCAL_MODE_COLUMN,
+        LOCAL_VERSION_COLUMN,
+        LOCAL_PORT_COLUMN
+    };
+    enum
+    {
+        HOST_STATUS_COLUMN = 0,
+        HOST_NAME_COLUMN,
+        HOST_PORT_COLUMN
+    };
 
     bool readXMLDrivers();
     bool readINDIHosts();
-    void processXMLDriver(QString & driverName);
-    bool buildDeviceGroup  (XMLEle *root, char errmsg[]);
+    void processXMLDriver(QString &driverName);
+    bool buildDeviceGroup(XMLEle *root, char errmsg[]);
     bool buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, DeviceFamily groupType, char errmsg[]);
 
     QTreeWidgetItem *lastGroup;
@@ -97,23 +105,23 @@ public:
     void processLocalTree(bool dState);
     void processRemoteTree(bool dState);
 
-    DriverInfo * findDriverByName(const QString &name);
-    DriverInfo * findDriverByLabel(const QString &label);
-    DriverInfo * findDriverByExec(const QString &exec);
+    DriverInfo *findDriverByName(const QString &name);
+    DriverInfo *findDriverByLabel(const QString &label);
+    DriverInfo *findDriverByExec(const QString &exec);
 
     ClientManager *getClientManager(DriverInfo *dv);
 
-    const QList<DriverInfo *> & getDrivers() { return driversList; }
+    const QList<DriverInfo *> &getDrivers() { return driversList; }
 
-    const QStringList & getDriversStringList() { return driversStringList; }
+    const QStringList &getDriversStringList() { return driversStringList; }
 
-    void getUniqueHosts(QList<DriverInfo*> & dList, QList < QList<DriverInfo *> > & uHosts);
+    void getUniqueHosts(QList<DriverInfo *> &dList, QList<QList<DriverInfo *>> &uHosts);
 
-    void addDriver(DriverInfo *di) { driversList.append(di) ; }
-    void removeDriver(DriverInfo *di) { driversList.removeOne(di) ; }
+    void addDriver(DriverInfo *di) { driversList.append(di); }
+    void removeDriver(DriverInfo *di) { driversList.removeOne(di); }
 
-    bool startDevices(QList<DriverInfo*> & dList);
-    void stopDevices(const QList<DriverInfo*> & dList);
+    bool startDevices(QList<DriverInfo *> &dList);
+    void stopDevices(const QList<DriverInfo *> &dList);
 
     bool connectRemoteHost(DriverInfo *dv);
     bool disconnectRemoteHost(DriverInfo *dv);
@@ -122,11 +130,11 @@ public:
 
     void clearServers();
 
-private:
+  private:
     DriverManager(QWidget *parent);
     ~DriverManager();
 
-    static DriverManager * _DriverManager;
+    static DriverManager *_DriverManager;
 
     ServerMode connectionMode;
 
@@ -140,7 +148,7 @@ private:
 
     INDIDBus indiDBUS;
 
-public slots:
+  public slots:
     //void enableDevice(INDI_D *device);
     //void disableDevice(INDI_D *device);
 
@@ -161,20 +169,18 @@ public slots:
     void updateCustomDrivers();
 
     void processClientTermination(ClientManager *client);
-    void processServerTermination(ServerManager* server);
+    void processServerTermination(ServerManager *server);
 
     void processDeviceStatus(DriverInfo *dv);
 
-signals:
+  signals:
     void clientTerminated(ClientManager *);
-    void serverTerminated(const QString & host, const QString & port);
+    void serverTerminated(const QString &host, const QString &port);
 
     /*
-signals:
-    void newDevice();
-    void newTelescope();
-    void newCCD();
-    */
+        signals:
+        void newDevice();
+        void newTelescope();
+        void newCCD();
+        */
 };
-
-#endif
