@@ -13,8 +13,6 @@
 
 namespace ISD
 {
-
-
 void DustCap::processLight(ILightVectorProperty *lvp)
 {
     DeviceDecorator::processLight(lvp);
@@ -22,14 +20,12 @@ void DustCap::processLight(ILightVectorProperty *lvp)
 
 void DustCap::processNumber(INumberVectorProperty *nvp)
 {
-
     DeviceDecorator::processNumber(nvp);
 }
 
 void DustCap::processSwitch(ISwitchVectorProperty *svp)
 {
     DeviceDecorator::processSwitch(svp);
-
 }
 
 void DustCap::processText(ITextVectorProperty *tvp)
@@ -37,11 +33,11 @@ void DustCap::processText(ITextVectorProperty *tvp)
     DeviceDecorator::processText(tvp);
 }
 
-
 bool DustCap::canPark()
 {
     ISwitchVectorProperty *parkSP = baseDevice->getSwitch("CAP_PARK");
-    if (parkSP == NULL)
+
+    if (parkSP == nullptr)
         return false;
     else
         return true;
@@ -50,7 +46,8 @@ bool DustCap::canPark()
 bool DustCap::isParked()
 {
     ISwitchVectorProperty *parkSP = baseDevice->getSwitch("CAP_PARK");
-    if (parkSP == NULL)
+
+    if (parkSP == nullptr)
         return false;
 
     return (parkSP->s == IPS_OK && parkSP->sp[0].s == ISS_ON);
@@ -59,41 +56,46 @@ bool DustCap::isParked()
 bool DustCap::Park()
 {
     ISwitchVectorProperty *parkSP = baseDevice->getSwitch("CAP_PARK");
-    if (parkSP == NULL)
+
+    if (parkSP == nullptr)
         return false;
 
     ISwitch *parkSW = IUFindSwitch(parkSP, "PARK");
-    if (parkSW == NULL)
+
+    if (parkSW == nullptr)
         return false;
 
-     IUResetSwitch(parkSP);
-     parkSW->s = ISS_ON;
-     clientManager->sendNewSwitch(parkSP);
+    IUResetSwitch(parkSP);
+    parkSW->s = ISS_ON;
+    clientManager->sendNewSwitch(parkSP);
 
-     return true;
+    return true;
 }
 
 bool DustCap::UnPark()
 {
     ISwitchVectorProperty *parkSP = baseDevice->getSwitch("CAP_PARK");
-    if (parkSP == NULL)
+
+    if (parkSP == nullptr)
         return false;
 
     ISwitch *parkSW = IUFindSwitch(parkSP, "UNPARK");
-    if (parkSW == NULL)
+
+    if (parkSW == nullptr)
         return false;
 
-     IUResetSwitch(parkSP);
-     parkSW->s = ISS_ON;
-     clientManager->sendNewSwitch(parkSP);
+    IUResetSwitch(parkSP);
+    parkSW->s = ISS_ON;
+    clientManager->sendNewSwitch(parkSP);
 
-     return true;
+    return true;
 }
 
 bool DustCap::hasLight()
 {
     ISwitchVectorProperty *lightSP = baseDevice->getSwitch("FLAT_LIGHT_CONTROL");
-    if (lightSP == NULL)
+
+    if (lightSP == nullptr)
         return false;
     else
         return true;
@@ -102,11 +104,13 @@ bool DustCap::hasLight()
 bool DustCap::isLightOn()
 {
     ISwitchVectorProperty *lightSP = baseDevice->getSwitch("FLAT_LIGHT_CONTROL");
-    if (lightSP == NULL)
+
+    if (lightSP == nullptr)
         return false;
 
-    ISwitch *lightON  = IUFindSwitch(lightSP, "FLAT_LIGHT_ON");
-    if (lightON == NULL)
+    ISwitch *lightON = IUFindSwitch(lightSP, "FLAT_LIGHT_ON");
+
+    if (lightON == nullptr)
         return false;
 
     return (lightON->s == ISS_ON);
@@ -115,20 +119,22 @@ bool DustCap::isLightOn()
 bool DustCap::SetLightEnabled(bool enable)
 {
     ISwitchVectorProperty *lightSP = baseDevice->getSwitch("FLAT_LIGHT_CONTROL");
-    if (lightSP == NULL)
+
+    if (lightSP == nullptr)
         return false;
 
     ISwitch *lightON  = IUFindSwitch(lightSP, "FLAT_LIGHT_ON");
     ISwitch *lightOFF = IUFindSwitch(lightSP, "FLAT_LIGHT_OFF");
-    if (lightON == NULL || lightOFF == NULL)
+
+    if (lightON == nullptr || lightOFF == nullptr)
         return false;
 
     IUResetSwitch(lightSP);
 
-   if (enable)
-       lightON->s  = ISS_ON;
-   else
-       lightOFF->s  = ISS_ON;
+    if (enable)
+        lightON->s = ISS_ON;
+    else
+        lightOFF->s = ISS_ON;
 
     clientManager->sendNewSwitch(lightSP);
 
@@ -147,5 +153,4 @@ bool DustCap::SetBrightness(uint16_t val)
 
     return false;
 }
-
 }
