@@ -39,8 +39,6 @@
 #include <KActionCollection>
 #include <KIconLoader>
 
-
-
 #include "oal/log.h"
 #include "oal/scope.h"
 #include "indimenu.h"
@@ -56,14 +54,13 @@
 #include <config-kstars.h>
 #include <QStandardPaths>
 
-#define  MAX_RETRIES 3
-#define  ERRMSG_SIZE 1024
+#define MAX_RETRIES 3
+#define ERRMSG_SIZE 1024
 
 DeviceManagerUI::DeviceManagerUI(QWidget *parent) : QFrame(parent)
 {
-
 #ifdef Q_OS_OSX
-        setWindowFlags(Qt::Tool| Qt::WindowStaysOnTopHint);
+    setWindowFlags(Qt::Tool | Qt::WindowStaysOnTopHint);
 #endif
     setupUi(this);
 
@@ -72,56 +69,53 @@ DeviceManagerUI::DeviceManagerUI(QWidget *parent) : QFrame(parent)
 
     clientTreeWidget->setSortingEnabled(false);
 
-    runningPix = QIcon::fromTheme( "system-run" );
-    stopPix    = QIcon::fromTheme( "dialog-cancel" );
-    localMode  = QIcon::fromTheme( "computer" );
-    serverMode = QIcon::fromTheme( "network-server" );
+    runningPix = QIcon::fromTheme("system-run");
+    stopPix    = QIcon::fromTheme("dialog-cancel");
+    localMode  = QIcon::fromTheme("computer");
+    serverMode = QIcon::fromTheme("network-server");
 
-    connected           = QIcon::fromTheme( "network-connect" );
-    disconnected        = QIcon::fromTheme( "network-disconnect" );
-
-    connect(localTreeWidget, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(makePortEditable(QTreeWidgetItem*,int)));
+    connected    = QIcon::fromTheme("network-connect");
+    disconnected = QIcon::fromTheme("network-disconnect");
 
+    connect(localTreeWidget, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this,
+            SLOT(makePortEditable(QTreeWidgetItem *, int)));
 }
 
-void DeviceManagerUI::makePortEditable(QTreeWidgetItem* selectedItem, int column)
+void DeviceManagerUI::makePortEditable(QTreeWidgetItem *selectedItem, int column)
 {
     // If it's the port column, then make it user-editable
     if (column == INDIDriver::LOCAL_PORT_COLUMN)
-        selectedItem->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEditable|Qt::ItemIsEnabled);
+        selectedItem->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsEnabled);
 
     localTreeWidget->editItem(selectedItem, INDIDriver::LOCAL_PORT_COLUMN);
 }
 
-INDIDriver::INDIDriver( KStars *_ks )
-        : QDialog( _ks ),  ksw( _ks )
+INDIDriver::INDIDriver(KStars *_ks) : QDialog(_ks), ksw(_ks)
 {
+    currentPort = Options::serverPortStart().toInt() - 1;
+    lastGroup   = nullptr;
+    lastDevice  = nullptr;
 
-    currentPort = Options::serverPortStart().toInt()-1;
-    lastGroup = NULL;
-    lastDevice = NULL;
+    ui = new DeviceManagerUI(this);
+    setMainWidget(ui);
+    setCaption(xi18n("Device Manager"));
+    setButtons(QDialog::Close);
 
-    ui = new DeviceManagerUI( this );
-    setMainWidget( ui );
-    setCaption( xi18n( "Device Manager" ) );
-    setButtons( QDialog::Close );
-
-    foreach ( INDIHostsInfo * host, ksw->data()->INDIHostsList )
+    foreach (INDIHostsInfo *host, ksw->data()->INDIHostsList)
     {
         QTreeWidgetItem *item = new QTreeWidgetItem(ui->clientTreeWidget, lastGroup);
-        lastGroup = item;
+        lastGroup             = item;
         item->setIcon(HOST_STATUS_COLUMN, ui->disconnected);
         item->setText(HOST_NAME_COLUMN, host->name);
         item->setText(HOST_PORT_COLUMN, host->portnumber);
     }
 
-    lastGroup = NULL;
+    lastGroup = nullptr;
 
     QObject::connect(ui->addB, SIGNAL(clicked()), this, SLOT(addINDIHost()));
     QObject::connect(ui->modifyB, SIGNAL(clicked()), this, SLOT(modifyINDIHost()));
     QObject::connect(ui->removeB, SIGNAL(clicked()), this, SLOT(removeINDIHost()));
-  
-  
+
     //QObject::connect(ksw->indiMenu(), SIGNAL(driverDisconnected(int)), this, SLOT(shutdownHost(int)));
     QObject::connect(ui->connectHostB, SIGNAL(clicked()), this, SLOT(activateHostConnection()));
     QObject::connect(ui->disconnectHostB, SIGNAL(clicked()), this, SLOT(activateHostDisconnection()));
@@ -130,16 +124,16 @@ INDIDriver::INDIDriver( KStars *_ks )
     QObject::connect(ui->localTreeWidget, SIGNAL(itemClicked(QTreeWidgetItem *, int)), this, SLOT(updateLocalTab()));
     QObject::connect(ui->clientTreeWidget, SIGNAL(itemClicked(QTreeWidgetItem *, int)), this, SLOT(updateClientTab()));
     QObject::connect(ui->localTreeWidget, SIGNAL(expanded(const QModelIndex &)), this, SLOT(resizeDeviceColumn()));
-  
+
     readXMLDrivers();
 }
-  
+
 /*
 void INDIDriver::enableDevice(INDI_D *indi_device)
 {
-   if (indi_device == NULL)
+   if (indi_device == nullptr)
 	return;
-  
+
    if (indi_device->deviceManager->mode == DeviceManager::M_CLIENT)
    {
    	foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
@@ -149,7 +143,7 @@ void INDIDriver::enableDevice(INDI_D *indi_device)
 	        {
 	    		foreach (QTreeWidgetItem *item, ui->clientTreeWidget->findItems(host->name, Qt::MatchExactly, 1))
                                 item->setIcon(HOST_STATUS_COLUMN, ui->connected);
-	
+
              		host->isConnected = true;
 			updateClientTab();
 			updateMenuActions();
@@ -169,7 +163,7 @@ void INDIDriver::enableDevice(INDI_D *indi_device)
                                 item->setIcon(LOCAL_STATUS_COLUMN, ui->runningPix);
                                 item->setText(LOCAL_PORT_COLUMN, QString::number(indi_device->deviceManager->port));
 			}
-			
+
 			updateLocalTab();
 			updateMenuActions();
 			ksw->indiMenu()->show();
@@ -177,12 +171,12 @@ void INDIDriver::enableDevice(INDI_D *indi_device)
 		}
 	}
       }
-  
+
 }
-  
+
 void INDIDriver::disableDevice(INDI_D *indi_device)
 {
-    if (indi_device == NULL)
+    if (indi_device == nullptr)
 	return;
 
    if (indi_device->deviceManager->mode == DeviceManager::M_CLIENT)
@@ -193,10 +187,10 @@ void INDIDriver::disableDevice(INDI_D *indi_device)
 	        {
 	    		foreach (QTreeWidgetItem *item, ui->clientTreeWidget->findItems(host->name, Qt::MatchExactly,1))
                                 item->setIcon(HOST_STATUS_COLUMN, ui->disconnected);
-	
-			host->deviceManager = NULL;
+
+			host->deviceManager = nullptr;
 		        host->isConnected = false;
-            
+
           		updateClientTab();
              		return;
         	}
@@ -214,10 +208,10 @@ void INDIDriver::disableDevice(INDI_D *indi_device)
                                 item->setIcon(LOCAL_MODE_COLUMN, QIcon());
                                 item->setText(LOCAL_PORT_COLUMN, device->port);
 			}
-			
+
 			device->clear();
 			updateLocalTab();
-			
+
 			return;
 		}
 	}
@@ -225,140 +219,139 @@ void INDIDriver::disableDevice(INDI_D *indi_device)
   }
   */
 void INDIDriver::activateRunService()
-  {
+{
     processLocalTree(IDevice::DEV_START);
-  }
-  
+}
+
 void INDIDriver::activateStopService()
-  {
+{
     processLocalTree(IDevice::DEV_TERMINATE);
-  }
-  
+}
+
 void INDIDriver::activateHostConnection()
-  {
+{
     processRemoteTree(IDevice::DEV_START);
-  }
-  
+}
+
 void INDIDriver::activateHostDisconnection()
-  {
+{
     processRemoteTree(IDevice::DEV_TERMINATE);
-  }
-  
+}
+
 void INDIDriver::updateLocalTab()
-  {
-  
-      if (ui->localTreeWidget->currentItem() == NULL)
-          return;
-  
+{
+    if (ui->localTreeWidget->currentItem() == nullptr)
+        return;
+
     foreach (IDevice *device, devices)
-      {
-  
+    {
         if (ui->localTreeWidget->currentItem()->text(LOCAL_NAME_COLUMN) == device->tree_label)
-          {
+        {
             ui->runServiceB->setEnabled(device->state == IDevice::DEV_TERMINATE);
             ui->stopServiceB->setEnabled(device->state == IDevice::DEV_START);
-  
-              ui->serverLogText->clear();
+
+            ui->serverLogText->clear();
             ui->serverLogText->append(device->getServerBuffer());
-  
-              return;
-          }
-	}
+
+            return;
+        }
+    }
 }
 
 void INDIDriver::updateClientTab()
 {
-     if (ui->clientTreeWidget->currentItem() == NULL)
+    if (ui->clientTreeWidget->currentItem() == nullptr)
         return;
 
-    foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
+    foreach (INDIHostsInfo *host, ksw->data()->INDIHostsList)
     {
-        if (ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN) == host->name && ui->clientTreeWidget->currentItem()->text(HOST_PORT_COLUMN) == host->portnumber)
+        if (ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN) == host->name &&
+            ui->clientTreeWidget->currentItem()->text(HOST_PORT_COLUMN) == host->portnumber)
         {
             ui->connectHostB->setEnabled(!host->isConnected);
             ui->disconnectHostB->setEnabled(host->isConnected);
             break;
         }
     }
-
 }
 
 void INDIDriver::processLocalTree(IDevice::DeviceStatus dev_request)
 {
-   QList<IDevice *> processed_devices;
-   DeviceManager *deviceManager=NULL;
+    QList<IDevice *> processed_devices;
+    DeviceManager *deviceManager = nullptr;
+    int port                     = 0;
+    bool portOK                  = false;
 
-   int port=0;
-   bool portOK=false;
+    foreach (QTreeWidgetItem *item, ui->localTreeWidget->selectedItems())
+    {
+        foreach (IDevice *device, devices)
+        {
+            //device->state = (dev_request == IDevice::DEV_TERMINATE) ? IDevice::DEV_START : IDevice::DEV_TERMINATE;
+            if (item->text(LOCAL_NAME_COLUMN) == device->tree_label && device->state != dev_request)
+            {
+                processed_devices.append(device);
 
-   foreach(QTreeWidgetItem *item, ui->localTreeWidget->selectedItems())
-   {
-      foreach (IDevice *device, devices)
-      {
-		//device->state = (dev_request == IDevice::DEV_TERMINATE) ? IDevice::DEV_START : IDevice::DEV_TERMINATE;
-                if (item->text(LOCAL_NAME_COLUMN) == device->tree_label && device->state != dev_request)
+                // N.B. If multiple devices are selected to run under one device manager
+                // then we select the port for the first device that has a valid port
+                // entry, the rest are ignored.
+                if (port == 0 && item->text(LOCAL_PORT_COLUMN).isEmpty() == false)
                 {
-			processed_devices.append(device);
-
-                        // N.B. If multiple devices are selected to run under one device manager
-                        // then we select the port for the first device that has a valid port
-                        // entry, the rest are ignored.
-                        if (port == 0 && item->text(LOCAL_PORT_COLUMN).isEmpty() == false)
-                        {
-                            port = item->text(LOCAL_PORT_COLUMN).toInt(&portOK);
-                            // If we encounter conversion error, we abort
-                            if (portOK == false)
-                            {
-                                KMessageBox::error(0, xi18n("Invalid port entry: %1", item->text(LOCAL_PORT_COLUMN)));
-                                return;
-                            }
-                        }
+                    port = item->text(LOCAL_PORT_COLUMN).toInt(&portOK);
+                    // If we encounter conversion error, we abort
+                    if (portOK == false)
+                    {
+                        KMessageBox::error(0, xi18n("Invalid port entry: %1", item->text(LOCAL_PORT_COLUMN)));
+                        return;
+                    }
                 }
-       }
-   }
+            }
+        }
+    }
 
-   if (processed_devices.empty()) return;
+    if (processed_devices.empty())
+        return;
 
-   // Select random port within range is none specified.
+    // Select random port within range is none specified.
     port = getINDIPort(port);
 
-   if (dev_request == IDevice::DEV_START)
-   {
-
+    if (dev_request == IDevice::DEV_START)
+    {
         if (port <= 0)
         {
-	        KMessageBox::error(0, xi18n("Cannot start INDI server: port error."));
-        	return;
-    	}
-   
-	//deviceManager = ksw->indiMenu()->startDeviceManager(processed_devices, ui->localR->isChecked() ? DeviceManager::M_LOCAL : DeviceManager::M_SERVER, ((uint) port));
-        deviceManager = ksw->indiMenu()->initDeviceManager("localhost", ((uint) port), ui->localR->isChecked() ? DeviceManager::M_LOCAL : DeviceManager::M_SERVER);
+            KMessageBox::error(0, xi18n("Cannot start INDI server: port error."));
+            return;
+        }
 
-	if (deviceManager == NULL)
-	{
-		kWarning() << "Warning: device manager has not been established properly";
-		return;
-	}
+        //deviceManager = ksw->indiMenu()->startDeviceManager(processed_devices, ui->localR->isChecked() ? DeviceManager::M_LOCAL : DeviceManager::M_SERVER, ((uint) port));
+        deviceManager = ksw->indiMenu()->initDeviceManager(
+            "localhost", ((uint)port), ui->localR->isChecked() ? DeviceManager::M_LOCAL : DeviceManager::M_SERVER);
 
-	deviceManager->appendManagedDevices(processed_devices);
-	deviceManager->startServer();
-	connect(deviceManager, SIGNAL(newServerInput()), this, SLOT(updateLocalTab()));
-   }
-   else
-	ksw->indiMenu()->stopDeviceManager(processed_devices);
+        if (deviceManager == nullptr)
+        {
+            kWarning() << "Warning: device manager has not been established properly";
+            return;
+        }
 
+        deviceManager->appendManagedDevices(processed_devices);
+        deviceManager->startServer();
+        connect(deviceManager, SIGNAL(newServerInput()), this, SLOT(updateLocalTab()));
+    }
+    else
+        ksw->indiMenu()->stopDeviceManager(processed_devices);
 }
 
 void INDIDriver::processRemoteTree(IDevice::DeviceStatus dev_request)
 {
-      DeviceManager* deviceManager=NULL;
-      QTreeWidgetItem *currentItem = ui->clientTreeWidget->currentItem();
-      if (!currentItem) return;
-     bool toConnect = (dev_request == IDevice::DEV_START);
+    DeviceManager *deviceManager = nullptr;
+    QTreeWidgetItem *currentItem = ui->clientTreeWidget->currentItem();
+    if (!currentItem)
+        return;
+    bool toConnect = (dev_request == IDevice::DEV_START);
 
-    foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
-     {
-        if (currentItem->text(HOST_NAME_COLUMN) == host->name && currentItem->text(HOST_PORT_COLUMN) == host->portnumber)
+    foreach (INDIHostsInfo *host, ksw->data()->INDIHostsList)
+    {
+        if (currentItem->text(HOST_NAME_COLUMN) == host->name &&
+            currentItem->text(HOST_PORT_COLUMN) == host->portnumber)
         {
             // Nothing changed, return
             if (host->isConnected == toConnect)
@@ -367,42 +360,40 @@ void INDIDriver::processRemoteTree(IDevice::DeviceStatus dev_request)
             // connect to host
             if (toConnect)
             {
-		deviceManager = ksw->indiMenu()->initDeviceManager(host->hostname, host->portnumber.toUInt(), DeviceManager::M_CLIENT);
-  
-	        if (deviceManager == NULL)
-		{
-			// msgbox after freeze
-			kWarning() << "Warning: device manager has not been established properly";
-		        return;
-		}
-  
-		host->deviceManager = deviceManager;
-		deviceManager->connectToServer();
-	     }
-             else
-             	ksw->indiMenu()->removeDeviceManager(host->deviceManager);
-  
-		return;
-	  }
+                deviceManager = ksw->indiMenu()->initDeviceManager(host->hostname, host->portnumber.toUInt(),
+                                                                   DeviceManager::M_CLIENT);
+
+                if (deviceManager == nullptr)
+                {
+                    // msgbox after freeze
+                    kWarning() << "Warning: device manager has not been established properly";
+                    return;
+                }
+
+                host->deviceManager = deviceManager;
+                deviceManager->connectToServer();
+            }
+            else
+                ksw->indiMenu()->removeDeviceManager(host->deviceManager);
+
+            return;
+        }
     }
 }
 
 void INDIDriver::newTelescopeDiscovered()
 {
-
     emit newTelescope();
-
 }
 
 void INDIDriver::newCCDDiscovered()
 {
-
     emit newCCD();
 }
 
 void INDIDriver::resizeDeviceColumn()
 {
-  ui->localTreeWidget->resizeColumnToContents(0);
+    ui->localTreeWidget->resizeColumnToContents(0);
 }
 
 void INDIDriver::updateMenuActions()
@@ -410,23 +401,22 @@ void INDIDriver::updateMenuActions()
     // We iterate over devices, we enable INDI Control Panel if we have any active device
     // We enable capture image sequence if we have any imaging device
 
-    QAction *tmpAction = NULL;
-    INDIMenu *devMenu = ksw->indiMenu();
-    bool activeDevice = false;
+    QAction *tmpAction = nullptr;
+    INDIMenu *devMenu  = ksw->indiMenu();
+    bool activeDevice  = false;
     bool activeImaging = false;
-    INDI_P *imgProp = NULL;
+    INDI_P *imgProp    = nullptr;
 
-    if (devMenu == NULL)
+    if (devMenu == nullptr)
         return;
 
     if (devMenu->managers.count() > 0)
         activeDevice = true;
 
-    foreach(DeviceManager *dev_managers, devMenu->managers)
+    foreach (DeviceManager *dev_managers, devMenu->managers)
     {
         foreach (INDI_D *device, dev_managers->indi_dev)
         {
-
             imgProp = device->findProp("CCD_EXPOSURE");
             if (imgProp && device->isOn())
             {
@@ -438,18 +428,18 @@ void INDIDriver::updateMenuActions()
 
     tmpAction = ksw->actionCollection()->action("capture_sequence");
 
-    if (tmpAction != NULL)
+    if (tmpAction != nullptr)
         tmpAction->setEnabled(activeImaging);
 
     tmpAction = ksw->actionCollection()->action("indi_cpl");
-    if (tmpAction != NULL)
-       tmpAction->setEnabled(activeDevice);
-
+    if (tmpAction != nullptr)
+        tmpAction->setEnabled(activeDevice);
 }
 
 bool INDIDriver::isDeviceRunning(const QString &deviceLabel)
 {
-    foreach(IDevice *dev, devices) {
+    foreach (IDevice *dev, devices)
+    {
         if (deviceLabel == dev->tree_label)
             return dev->state == IDevice::DEV_START;
     }
@@ -458,13 +448,14 @@ bool INDIDriver::isDeviceRunning(const QString &deviceLabel)
 
 int INDIDriver::getINDIPort(int customPort)
 {
-
-    int lastPort  = Options::serverPortEnd().toInt();;
+    int lastPort = Options::serverPortEnd().toInt();
+    ;
     bool success = false;
     currentPort++;
 
     // recycle
-    if (currentPort > lastPort) currentPort = Options::serverPortStart().toInt();
+    if (currentPort > lastPort)
+        currentPort = Options::serverPortStart().toInt();
 
     QTcpServer temp_server;
 
@@ -480,10 +471,10 @@ int INDIDriver::getINDIPort(int customPort)
             return -1;
     }
 
-    for(; currentPort <= lastPort; currentPort++)
+    for (; currentPort <= lastPort; currentPort++)
     {
-            success = temp_server.listen(QHostAddress::LocalHost, currentPort);
-        if(success)
+        success = temp_server.listen(QHostAddress::LocalHost, currentPort);
+        if (success)
         {
             temp_server.close();
             return currentPort;
@@ -497,17 +488,19 @@ bool INDIDriver::readXMLDrivers()
     QDir indiDir;
     QString driverName;
 
-    QString driversDir=Options::indiDriversDir();
-     #ifdef Q_OS_OSX
-    if(Options::indiDriversAreInternal())
-        driversDir=QCoreApplication::applicationDirPath()+"/indi";
-    #endif
+    QString driversDir = Options::indiDriversDir();
+#ifdef Q_OS_OSX
+    if (Options::indiDriversAreInternal())
+        driversDir = QCoreApplication::applicationDirPath() + "/indi";
+#endif
 
     if (indiDir.cd(driversDir) == false)
     {
-        KMessageBox::error(0, xi18n("Unable to find INDI Drivers directory: %1\nPlease make sure to set the correct path in KStars configuration", driversDir));
-          return false;
-     }
+        KMessageBox::error(0, xi18n("Unable to find INDI Drivers directory: %1\nPlease make sure to set the correct "
+                                    "path in KStars configuration",
+                                    driversDir));
+        return false;
+    }
 
     indiDir.setNameFilters(QStringList("*.xml"));
     indiDir.setFilter(QDir::Files | QDir::NoSymLinks);
@@ -519,48 +512,47 @@ bool INDIDriver::readXMLDrivers()
         if (fileInfo.fileName().endsWith("_sk.xml"))
             continue;
 
-	if (fileInfo.fileName() == "drivers.xml")
-	{ 
-	    // Let first attempt to load the local version of drivers.xml
-	    driverName = KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "drivers.xml";
+        if (fileInfo.fileName() == "drivers.xml")
+        {
+            // Let first attempt to load the local version of drivers.xml
+            driverName =
+                KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "drivers.xml";
 
-	    // If found, we continue, otherwise, we load the system file
-	    if (driverName.isEmpty() == false && QFile(driverName).exists())
-	    {
-	        processXMLDriver(driverName);
-		continue;
-	    }
-	}
-
-            driverName = QString("%1/%2").arg(driversDir).arg(fileInfo.fileName());
-	        processXMLDriver(driverName);
+            // If found, we continue, otherwise, we load the system file
+            if (driverName.isEmpty() == false && QFile(driverName).exists())
+            {
+                processXMLDriver(driverName);
+                continue;
+            }
+        }
 
+        driverName = QString("%1/%2").arg(driversDir).arg(fileInfo.fileName());
+        processXMLDriver(driverName);
     }
 
-return true;
-
+    return true;
 }
 
-void INDIDriver::processXMLDriver(QString & driverName)
+void INDIDriver::processXMLDriver(QString &driverName)
 {
     QFile file(driverName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     {
         KMessageBox::error(0, xi18n("Failed to open INDI Driver file: %1", driverName));
-         return;
+        return;
     }
 
     char errmsg[ERRMSG_SIZE];
     char c;
     LilXML *xmlParser = newLilXML();
-    XMLEle *root = NULL;
+    XMLEle *root      = nullptr;
 
     if (driverName.endsWith("drivers.xml"))
         xmlSource = IDevice::PRIMARY_XML;
     else
         xmlSource = IDevice::THIRD_PARTY_XML;
 
-    while ( file.getChar(&c))
+    while (file.getChar(&c))
     {
         root = readXMLEle(xmlParser, c, errmsg);
 
@@ -580,12 +572,10 @@ void INDIDriver::processXMLDriver(QString & driverName)
     }
 
     delLilXML(xmlParser);
-
 }
 
 bool INDIDriver::buildDeviceGroup(XMLEle *root, char errmsg[])
 {
-
     XMLAtt *ap;
     XMLEle *ep;
     QString groupName;
@@ -640,14 +630,13 @@ bool INDIDriver::buildDeviceGroup(XMLEle *root, char errmsg[])
     group->setText(0, groupName);
     lastGroup = group;
 
-    for (ep = nextXMLEle(root, 1) ; ep != NULL ; ep = nextXMLEle(root, 0))
+    for (ep = nextXMLEle(root, 1); ep != nullptr; ep = nextXMLEle(root, 0))
         if (!buildDriverElement(ep, group, groupType, errmsg))
             return false;
 
     return true;
 }
 
-
 bool INDIDriver::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, int groupType, char errmsg[])
 {
     XMLAtt *ap;
@@ -658,56 +647,55 @@ bool INDIDriver::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, int g
     QString version;
     QString name;
     QString port;
-    double focal_length (-1), aperture (-1);
+    double focal_length(-1), aperture(-1);
 
+    ap = findXMLAtt(root, "label");
+    if (!ap)
+    {
+        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a label attribute", tagXMLEle(root));
+        return false;
+    }
 
-        ap = findXMLAtt(root, "label");
-        if (!ap)
-        {
-            snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a label attribute", tagXMLEle(root));
-            return false;
-        }
+    label = valuXMLAtt(ap);
 
-        label = valuXMLAtt(ap);
+    // Search for optional port attribute
+    ap = findXMLAtt(root, "port");
+    if (ap)
+        port = valuXMLAtt(ap);
 
-        // Search for optional port attribute
-        ap = findXMLAtt(root, "port");
-        if (ap)
-            port = valuXMLAtt(ap);
+    // Let's look for telescope-specific attributes: focal length and aperture
+    ap = findXMLAtt(root, "focal_length");
+    if (ap)
+        focal_length = QString(valuXMLAtt(ap)).toDouble();
 
-        // Let's look for telescope-specific attributes: focal length and aperture
-        ap = findXMLAtt(root, "focal_length");
-        if (ap)
-            focal_length = QString(valuXMLAtt(ap)).toDouble();
+    ap = findXMLAtt(root, "aperture");
+    if (ap)
+        aperture = QString(valuXMLAtt(ap)).toDouble();
 
-        ap = findXMLAtt(root, "aperture");
-        if (ap)
-            aperture = QString(valuXMLAtt(ap)).toDouble();
+    el = findXMLEle(root, "driver");
 
-        el = findXMLEle(root, "driver");
+    if (!el)
+        return false;
 
-        if (!el)
-            return false;
+    driver = pcdataXMLEle(el);
 
-        driver = pcdataXMLEle(el);
+    ap = findXMLAtt(el, "name");
+    if (!ap)
+    {
+        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a name attribute", tagXMLEle(el));
+        return false;
+    }
 
-        ap = findXMLAtt(el, "name");
-        if (!ap)
-        {
-            snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a name attribute", tagXMLEle(el));
-            return false;
-        }
+    name = valuXMLAtt(ap);
 
-        name = valuXMLAtt(ap);
+    el = findXMLEle(root, "version");
 
-        el = findXMLEle(root, "version");
+    if (!el)
+        return false;
 
-        if (!el)
-            return false;
+    version = pcdataXMLEle(el);
 
-        version = pcdataXMLEle(el);
-
-        QTreeWidgetItem *device = new QTreeWidgetItem(DGroup, lastDevice);
+    QTreeWidgetItem *device = new QTreeWidgetItem(DGroup, lastDevice);
 
     device->setText(LOCAL_NAME_COLUMN, label);
     device->setIcon(LOCAL_STATUS_COLUMN, ui->stopPix);
@@ -719,8 +707,8 @@ bool INDIDriver::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, int g
     if ((xmlSource == IDevice::PRIMARY_XML) && driversList.contains(driver) == false)
         driversList.insert(driver, name);
 
-    dv = new IDevice(name, label, driver, version);
-    dv->type = groupType;
+    dv            = new IDevice(name, label, driver, version);
+    dv->type      = groupType;
     dv->xmlSource = xmlSource;
     //connect(dv, SIGNAL(newServerInput()), this, SLOT(updateLocalTab()));
     if (focal_length > 0)
@@ -743,73 +731,74 @@ void INDIDriver::updateCustomDrivers()
     QString name;
     IDevice *dv;
     QTreeWidgetItem *group, *widgetDev;
-    double focal_length (-1), aperture (-1);
+    double focal_length(-1), aperture(-1);
 
     // Find if the group already exists
     QList<QTreeWidgetItem *> treeList = ui->localTreeWidget->findItems("Telescopes", Qt::MatchExactly);
     if (!treeList.isEmpty())
         group = treeList[0];
-    else return;
+    else
+        return;
 
+    // Find custom telescope to ADD
+    foreach (OAL::Scope *s, *(KStarsData::Instance()->logObject()->scopeList()))
+    {
+        label = s->vendor() + " " + s->model();
 
-        // Find custom telescope to ADD
-    foreach(OAL::Scope *s, *(KStarsData::Instance()->logObject()->scopeList()))
+        if (s->driver() == xi18n("None") || findDeviceByLabel(label))
+            continue;
+
+        QHash<QString, QString>::const_iterator i = driversList.constFind(s->driver());
+        if (i != driversList.constEnd() && i.key() == s->driver())
+            name = i.value();
+        else
+            return;
+        focal_length = s->focalLength();
+        aperture     = s->aperture();
+        driver       = s->driver();
+        version      = QString("1.0");
+
+        QTreeWidgetItem *device = new QTreeWidgetItem(group, lastDevice);
+        device->setText(LOCAL_NAME_COLUMN, QString(label));
+        device->setIcon(LOCAL_STATUS_COLUMN, ui->stopPix);
+        device->setText(LOCAL_VERSION_COLUMN, QString(version));
+
+        lastDevice = device;
+
+        dv               = new IDevice(name, label, driver, version);
+        dv->type         = KSTARS_TELESCOPE;
+        dv->xmlSource    = IDevice::EM_XML;
+        dv->focal_length = focal_length;
+        dv->aperture     = aperture;
+        dv->id           = s->id();
+        devices.append(dv);
+    }
+
+    // Find custom telescope to REMOVE
+    foreach (IDevice *dev, devices)
+    {
+        // If it's from primary xml file or it is in a running state, continue.
+        if (dev->xmlSource != IDevice::EM_XML || dev->state == IDevice::DEV_START)
+            continue;
+
+        // See if log object has the device, if not delete it
+        if (KStarsData::Instance()->logObject()->findScopeById(dev->id))
+            continue;
+
+        // Find if the group already exists
+        QList<QTreeWidgetItem *> devList =
+            ui->localTreeWidget->findItems(dev->tree_label, Qt::MatchExactly | Qt::MatchRecursive);
+        if (!devList.isEmpty())
         {
-            label = s->vendor() + " " + s->model();
-
-            if (s->driver() == xi18n("None") || findDeviceByLabel(label))
-                continue;
-
-            QHash<QString, QString>::const_iterator i = driversList.constFind(s->driver());
-            if (i != driversList.constEnd() && i.key() == s->driver())
-                name  = i.value();
-            else
-                return;
-            focal_length = s->focalLength();
-            aperture = s->aperture();
-            driver = s->driver();
-            version = QString("1.0");
-
-            QTreeWidgetItem *device = new QTreeWidgetItem(group, lastDevice);
-            device->setText(LOCAL_NAME_COLUMN, QString(label));
-            device->setIcon(LOCAL_STATUS_COLUMN, ui->stopPix);
-            device->setText(LOCAL_VERSION_COLUMN, QString(version));
-
-            lastDevice = device;
-
-            dv = new IDevice(name, label, driver, version);
-            dv->type = KSTARS_TELESCOPE;
-            dv->xmlSource = IDevice::EM_XML;
-            dv->focal_length = focal_length;
-            dv->aperture = aperture;
-            dv->id = s->id();
-            devices.append(dv);
-        }
-
-        // Find custom telescope to REMOVE
-        foreach(IDevice *dev, devices)
-        {
-            // If it's from primary xml file or it is in a running state, continue.
-            if (dev->xmlSource != IDevice::EM_XML || dev->state == IDevice::DEV_START)
-                continue;
-
-            // See if log object has the device, if not delete it
-            if (KStarsData::Instance()->logObject()->findScopeById(dev->id))
-                continue;
-
-            // Find if the group already exists
-            QList<QTreeWidgetItem *> devList = ui->localTreeWidget->findItems(dev->tree_label, Qt::MatchExactly  | Qt::MatchRecursive);
-            if (!devList.isEmpty())
-            {
-                widgetDev = devList[0];
-                group->removeChild(widgetDev);
-            }
-            else return;
-
-            devices.removeOne(dev);
-            delete (dev);
+            widgetDev = devList[0];
+            group->removeChild(widgetDev);
         }
+        else
+            return;
 
+        devices.removeOne(dev);
+        delete (dev);
+    }
 }
 
 void INDIDriver::addINDIHost()
@@ -823,11 +812,11 @@ void INDIDriver::addINDIHost()
     if (hostConfDialog.exec() == QDialog::Accepted)
     {
         INDIHostsInfo *hostItem = new INDIHostsInfo;
-        hostItem->name        	= hostConf.nameIN->text();
-        hostItem->hostname    	= hostConf.hostname->text();
-        hostItem->portnumber  	= hostConf.portnumber->text();
-        hostItem->isConnected 	= false;
-        hostItem->deviceManager	= NULL;
+        hostItem->name          = hostConf.nameIN->text();
+        hostItem->hostname      = hostConf.hostname->text();
+        hostItem->portnumber    = hostConf.portnumber->text();
+        hostItem->isConnected   = false;
+        hostItem->deviceManager = nullptr;
 
         hostItem->portnumber.toInt(&portOk);
 
@@ -840,13 +829,13 @@ void INDIDriver::addINDIHost()
 
         //search for duplicates
         //for (uint i=0; i < ksw->data()->INDIHostsList.count(); i++)
-        foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
-        if (hostItem->name   == host->name &&  hostItem->portnumber == host->portnumber)
-        {
-            KMessageBox::error(0, xi18n("Host: %1 Port: %2 already exists.", hostItem->name, hostItem->portnumber));
-            delete hostItem;
-            return;
-        }
+        foreach (INDIHostsInfo *host, ksw->data()->INDIHostsList)
+            if (hostItem->name == host->name && hostItem->portnumber == host->portnumber)
+            {
+                KMessageBox::error(0, xi18n("Host: %1 Port: %2 already exists.", hostItem->name, hostItem->portnumber));
+                delete hostItem;
+                return;
+            }
 
         ksw->data()->INDIHostsList.append(hostItem);
 
@@ -854,17 +843,13 @@ void INDIDriver::addINDIHost()
         item->setIcon(HOST_STATUS_COLUMN, ui->disconnected);
         item->setText(HOST_NAME_COLUMN, hostConf.nameIN->text());
         item->setText(HOST_PORT_COLUMN, hostConf.portnumber->text());
-
     }
 
     saveHosts();
 }
 
-
-
 void INDIDriver::modifyINDIHost()
 {
-
     QDialog hostConfDialog;
     Ui::INDIHostConf hostConf;
     hostConf.setupUi(&hostConfDialog);
@@ -872,12 +857,13 @@ void INDIDriver::modifyINDIHost()
 
     QTreeWidgetItem *currentItem = ui->clientTreeWidget->currentItem();
 
-    if (currentItem == NULL)
+    if (currentItem == nullptr)
         return;
 
-    foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
+    foreach (INDIHostsInfo *host, ksw->data()->INDIHostsList)
     {
-        if (currentItem->text(HOST_NAME_COLUMN) == host->name && currentItem->text(HOST_PORT_COLUMN) == host->portnumber)
+        if (currentItem->text(HOST_NAME_COLUMN) == host->name &&
+            currentItem->text(HOST_PORT_COLUMN) == host->portnumber)
         {
             hostConf.nameIN->setText(host->name);
             hostConf.hostname->setText(host->hostname);
@@ -900,60 +886,61 @@ void INDIDriver::modifyINDIHost()
             }
         }
     }
-
 }
 
 void INDIDriver::removeINDIHost()
 {
-
-    if (ui->clientTreeWidget->currentItem() == NULL)
+    if (ui->clientTreeWidget->currentItem() == nullptr)
         return;
 
-    for (int i=0; i < ksw->data()->INDIHostsList.count(); i++)
+    for (int i = 0; i < ksw->data()->INDIHostsList.count(); i++)
+    {
         if (ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN) == ksw->data()->INDIHostsList[i]->name &&
-                ui->clientTreeWidget->currentItem()->text(HOST_PORT_COLUMN) == ksw->data()->INDIHostsList[i]->portnumber)
+            ui->clientTreeWidget->currentItem()->text(HOST_PORT_COLUMN) == ksw->data()->INDIHostsList[i]->portnumber)
         {
             if (ksw->data()->INDIHostsList[i]->isConnected)
             {
-                KMessageBox::error( 0, xi18n("You need to disconnect the client before removing it."));
+                KMessageBox::error(0, xi18n("You need to disconnect the client before removing it."));
                 return;
             }
 
-            if (KMessageBox::warningContinueCancel( 0, xi18n("Are you sure you want to remove the %1 client?", ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN)), xi18n("Delete Confirmation"),KStandardGuiItem::del())!=KMessageBox::Continue)
+            if (KMessageBox::warningContinueCancel(0,
+                                                   xi18n("Are you sure you want to remove the %1 client?",
+                                                         ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN)),
+                                                   xi18n("Delete Confirmation"),
+                                                   KStandardGuiItem::del()) != KMessageBox::Continue)
                 return;
 
             delete ksw->data()->INDIHostsList.takeAt(i);
             delete (ui->clientTreeWidget->currentItem());
             break;
         }
-
-
-
+    }
     saveHosts();
 }
 
 void INDIDriver::saveHosts()
 {
-
     QFile file;
     QString hostData;
 
-    file.setFileName( KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "indihosts.xml" ) ; //determine filename in local user KDE directory tree.
+    file.setFileName(KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') +
+                     "indihosts.xml"); //determine filename in local user KDE directory tree.
 
-    if ( !file.open( QIODevice::WriteOnly))
+    if (!file.open(QIODevice::WriteOnly))
     {
-        QString message = xi18n( "Unable to write to file 'indihosts.xml'\nAny changes to INDI hosts configurations will not be saved." );
-        KMessageBox::sorry( 0, message, xi18n( "Could Not Open File" ) );
+        QString message = xi18n(
+            "Unable to write to file 'indihosts.xml'\nAny changes to INDI hosts configurations will not be saved.");
+        KMessageBox::sorry(0, message, xi18n("Could Not Open File"));
         return;
     }
 
     QTextStream outstream(&file);
 
     //for (uint i= 0; i < ksw->data()->INDIHostsList.count(); i++)
-    foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
+    foreach (INDIHostsInfo *host, ksw->data()->INDIHostsList)
     {
-
-        hostData  = "<INDIHost name='";
+        hostData = "<INDIHost name='";
         hostData += host->name;
         hostData += "' hostname='";
         hostData += host->hostname;
@@ -962,80 +949,75 @@ void INDIDriver::saveHosts()
         hostData += "' />\n";
 
         outstream << hostData;
-
     }
 
     file.close();
-
 }
 
-IDevice * INDIDriver::findDeviceByLabel(const QString &label)
+IDevice *INDIDriver::findDeviceByLabel(const QString &label)
 {
-    foreach(IDevice *dev, devices)
+    foreach (IDevice *dev, devices)
+    {
         if (dev->tree_label == label)
             return dev;
-
-    return NULL;
+    }
+    return nullptr;
 }
 
 INDIDriver::~INDIDriver()
 {
-
     //for (uint i=0; i < devices.size(); i++)
     //delete (devices[i]);
     while (!devices.isEmpty())
         delete devices.takeFirst();
-
 }
 
 IDevice::IDevice(const QString &inName, const QString &inLabel, const QString &inDriver, const QString &inVersion)
 {
-    tree_label	 = inLabel;
+    tree_label = inLabel;
     unique_label.clear();
-    name = inName;
-    driver	 = inDriver;
-    version	 = inVersion;
+    name    = inName;
+    driver  = inDriver;
+    version = inVersion;
 
-    xmlSource  = PRIMARY_XML;
-  
-      // Initially off
+    xmlSource = PRIMARY_XML;
+
+    // Initially off
     state = IDevice::DEV_TERMINATE;
-  
-      // No port initially
+
+    // No port initially
     //indiPort = -1;
-  
-      // not yet managed by DeviceManager
+
+    // not yet managed by DeviceManager
     //managed = false;
-  
-    deviceManager = NULL;
-  
-      focal_length = -1;
-      aperture = -1;
-  
-    //proc = NULL;
-  
+
+    deviceManager = nullptr;
+
+    focal_length = -1;
+    aperture     = -1;
+
+    //proc = nullptr;
 }
-  
+
 IDevice::~IDevice()
 {
-
 }
-  
+
 void IDevice::clear()
 {
     //managed = false;
-    state = IDevice::DEV_TERMINATE;
-    deviceManager = NULL;
-  
+    state         = IDevice::DEV_TERMINATE;
+    deviceManager = nullptr;
+
     unique_label.clear();
 }
-  
+
 QString IDevice::getServerBuffer()
 {
-	if (deviceManager != NULL)
-		return deviceManager->getServerBuffer();
-  
-	return QString();
+    if (deviceManager != nullptr)
+        return deviceManager->getServerBuffer();
+
+    return QString();
 }
 
 #include "indidriver.moc"
