@@ -44,26 +44,25 @@ extern const char *libindi_strings_context;
 *******************************************************************/
 INDI_E::INDI_E(INDI_P *gProp, INDI::Property *dProp)
 {
-  guiProp  = gProp;
-  dataProp = dProp;
+    guiProp  = gProp;
+    dataProp = dProp;
 
-  EHBox     = new QHBoxLayout;
-  EHBox->setMargin(0);
-
-  tp        = NULL;
-  sp        = NULL;
-  np        = NULL;
-  label_w   = NULL;
-  read_w    = NULL;
-  write_w   = NULL;
-  spin_w    = NULL;
-  slider_w  = NULL;
-  push_w    = NULL;
-  browse_w  = NULL;
-  check_w   = NULL;
-  led_w     = NULL;
-  hSpacer   = NULL;
+    EHBox = new QHBoxLayout;
+    EHBox->setMargin(0);
 
+    tp       = nullptr;
+    sp       = nullptr;
+    np       = nullptr;
+    label_w  = nullptr;
+    read_w   = nullptr;
+    write_w  = nullptr;
+    spin_w   = nullptr;
+    slider_w = nullptr;
+    push_w   = nullptr;
+    browse_w = nullptr;
+    check_w  = nullptr;
+    led_w    = nullptr;
+    hSpacer  = nullptr;
 }
 
 INDI_E::~INDI_E()
@@ -81,7 +80,7 @@ INDI_E::~INDI_E()
     delete (hSpacer);
 }
 
-void INDI_E::buildSwitch(QButtonGroup* groupB, ISwitch *sw)
+void INDI_E::buildSwitch(QButtonGroup *groupB, ISwitch *sw)
 {
     name  = sw->name;
     label = i18nc(libindi_strings_context, sw->label);
@@ -97,57 +96,55 @@ void INDI_E::buildSwitch(QButtonGroup* groupB, ISwitch *sw)
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = sw->name;
 
-    if (groupB == NULL)
+    if (groupB == nullptr)
         return;
 
     switch (guiProp->getGUIType())
     {
-    case PG_BUTTONS:
-        push_w = new QPushButton(label, guiProp->getGroup()->getContainer());
-        push_w->setCheckable(true);
-        groupB->addButton(push_w);
+        case PG_BUTTONS:
+            push_w = new QPushButton(label, guiProp->getGroup()->getContainer());
+            push_w->setCheckable(true);
+            groupB->addButton(push_w);
 
-        syncSwitch();
+            syncSwitch();
 
-        guiProp->addWidget(push_w);
+            guiProp->addWidget(push_w);
 
-        push_w->show();
+            push_w->show();
 
-        if (sw->svp->p == IP_RO)
-            push_w->setEnabled(sw->s == ISS_ON);
+            if (sw->svp->p == IP_RO)
+                push_w->setEnabled(sw->s == ISS_ON);
 
-        break;
+            break;
 
-    case PG_RADIO:
-        check_w = new QCheckBox(label, guiProp->getGroup()->getContainer());
-        groupB->addButton(check_w);
+        case PG_RADIO:
+            check_w = new QCheckBox(label, guiProp->getGroup()->getContainer());
+            groupB->addButton(check_w);
 
-        syncSwitch();
+            syncSwitch();
 
-        guiProp->addWidget(check_w);
+            guiProp->addWidget(check_w);
 
-        check_w->show();
+            check_w->show();
 
-        if (sw->svp->p == IP_RO)
-            check_w->setEnabled(sw->s == ISS_ON);
+            if (sw->svp->p == IP_RO)
+                check_w->setEnabled(sw->s == ISS_ON);
 
-        break;
-
-    default:
-        break;
+            break;
 
+        default:
+            break;
     }
-
 }
 
 void INDI_E::buildMenuItem(ISwitch *sw)
 {
-    buildSwitch(NULL, sw);
+    buildSwitch(nullptr, sw);
 }
 
 void INDI_E::buildText(IText *itp)
 {
-    name  = itp->name;
+    name = itp->name;
     if (itp->label[0])
         label = i18nc(libindi_strings_context, itp->label);
 
@@ -169,22 +166,21 @@ void INDI_E::buildText(IText *itp)
 
     switch (dataProp->getPermission())
     {
-    case IP_RW:
-        setupElementRead(ELEMENT_READ_WIDTH);
-        setupElementWrite(ELEMENT_WRITE_WIDTH);
+        case IP_RW:
+            setupElementRead(ELEMENT_READ_WIDTH);
+            setupElementWrite(ELEMENT_WRITE_WIDTH);
 
-        break;
+            break;
 
-    case IP_RO:
-        setupElementRead(ELEMENT_FULL_WIDTH);
-        break;
+        case IP_RO:
+            setupElementRead(ELEMENT_FULL_WIDTH);
+            break;
 
-    case IP_WO:
-        setupElementWrite(ELEMENT_FULL_WIDTH);
-        break;
+        case IP_WO:
+            setupElementWrite(ELEMENT_FULL_WIDTH);
+            break;
     }
 
-
     guiProp->addLayout(EHBox);
     //pp->PVBox->addLayout(EHBox);
 }
@@ -196,19 +192,19 @@ void INDI_E::setupElementLabel()
     label_w = new KSqueezedTextLabel(guiProp->getGroup()->getContainer());
     label_w->setMinimumWidth(ELEMENT_LABEL_WIDTH);
     label_w->setMaximumWidth(ELEMENT_LABEL_WIDTH);
-    label_w->setFrameShape( KSqueezedTextLabel::Box );
+    label_w->setFrameShape(KSqueezedTextLabel::Box);
 
-    palette.setColor(label_w->backgroundRole(),  QColor( 224, 232, 238 ));
+    palette.setColor(label_w->backgroundRole(), QColor(224, 232, 238));
     label_w->setPalette(palette);
-    label_w->setTextFormat( Qt::RichText );
-    label_w->setAlignment( Qt::AlignCenter );
+    label_w->setTextFormat(Qt::RichText);
+    label_w->setAlignment(Qt::AlignCenter);
     label_w->setWordWrap(true);
 
     if (label.length() > MAX_LABEL_LENGTH)
     {
-        QFont tempFont(  label_w->font() );
-        tempFont.setPointSize( tempFont.pointSize() - MED_INDI_FONT );
-        label_w->setFont( tempFont );
+        QFont tempFont(label_w->font());
+        tempFont.setPointSize(tempFont.pointSize() - MED_INDI_FONT);
+        label_w->setFont(tempFont);
     }
 
     label_w->setText(label);
@@ -222,55 +218,54 @@ void INDI_E::syncSwitch()
 
     switch (guiProp->getGUIType())
     {
-       case PG_BUTTONS:
-        if (sp->s == ISS_ON)
-        {                       
-            push_w->setChecked(true);
-            //push_w->setDown(true);
-            buttonFont = push_w->font();
-            buttonFont.setBold(true);
-            push_w->setFont(buttonFont);
+        case PG_BUTTONS:
+            if (sp->s == ISS_ON)
+            {
+                push_w->setChecked(true);
+                //push_w->setDown(true);
+                buttonFont = push_w->font();
+                buttonFont.setBold(true);
+                push_w->setFont(buttonFont);
 
-            if (sp->svp->p == IP_RO)
-                push_w->setEnabled(true);
-        }
-        else
-        {            
-            push_w->setChecked(false);
-            //push_w->setDown(false);
-            buttonFont = push_w->font();
-            buttonFont.setBold(false);
-            push_w->setFont(buttonFont);
+                if (sp->svp->p == IP_RO)
+                    push_w->setEnabled(true);
+            }
+            else
+            {
+                push_w->setChecked(false);
+                //push_w->setDown(false);
+                buttonFont = push_w->font();
+                buttonFont.setBold(false);
+                push_w->setFont(buttonFont);
 
-            if (sp->svp->p == IP_RO)
-                push_w->setEnabled(false);
-        }
-        break;
+                if (sp->svp->p == IP_RO)
+                    push_w->setEnabled(false);
+            }
+            break;
 
-    case PG_RADIO:
-        if (sp->s == ISS_ON)
-        {
-            check_w->setChecked(true);
-            if (sp->svp->p == IP_RO)
-                check_w->setEnabled(true);
-        }
-        else
-        {
-            check_w->setChecked(false);
-            if (sp->svp->p == IP_RO)
-                check_w->setEnabled(false);
-        }
-        break;
-
-    default:
-        break;
+        case PG_RADIO:
+            if (sp->s == ISS_ON)
+            {
+                check_w->setChecked(true);
+                if (sp->svp->p == IP_RO)
+                    check_w->setEnabled(true);
+            }
+            else
+            {
+                check_w->setChecked(false);
+                if (sp->svp->p == IP_RO)
+                    check_w->setEnabled(false);
+            }
+            break;
 
+        default:
+            break;
     }
 }
 
 void INDI_E::syncText()
 {
-    if (tp == NULL)
+    if (tp == nullptr)
         return;
 
     if (tp->tvp->p != IP_WO)
@@ -289,9 +284,8 @@ void INDI_E::syncText()
 
 void INDI_E::syncNumber()
 {
-
     char iNumber[MAXINDIFORMAT];
-    if (np == NULL || read_w == NULL)
+    if (np == nullptr || read_w == nullptr)
         return;
 
     numberFormat(iNumber, np->format, np->value);
@@ -307,13 +301,11 @@ void INDI_E::syncNumber()
         if (np->max != spin_w->maximum())
             setMax();
     }
-
 }
 
 void INDI_E::updateTP()
 {
-
-    if (tp == NULL)
+    if (tp == nullptr)
         return;
 
     IUSaveText(tp, write_w->text().toLatin1().constData());
@@ -321,10 +313,10 @@ void INDI_E::updateTP()
 
 void INDI_E::updateNP()
 {
-    if (np == NULL)
+    if (np == nullptr)
         return;
 
-    if (write_w != NULL)
+    if (write_w != nullptr)
     {
         if (write_w->text().isEmpty())
             return;
@@ -333,31 +325,29 @@ void INDI_E::updateNP()
         return;
     }
 
-    if (spin_w != NULL)
+    if (spin_w != nullptr)
         np->value = spin_w->value();
-
 }
 
 void INDI_E::setText(const QString &newText)
 {
-    if (tp == NULL)
+    if (tp == nullptr)
         return;
 
-   switch(dataProp->getPermission())
-   {
-      case IP_RO:
-       read_w->setText(newText);
-       break;
-
-      case IP_WO:
-      case IP_RW:
-       text = newText;
-       IUSaveText(tp, newText.toLatin1().constData());
-       read_w->setText(newText);
-       write_w->setText(newText);
-        break;
-   }
+    switch (dataProp->getPermission())
+    {
+        case IP_RO:
+            read_w->setText(newText);
+            break;
 
+        case IP_WO:
+        case IP_RW:
+            text = newText;
+            IUSaveText(tp, newText.toLatin1().constData());
+            read_w->setText(newText);
+            write_w->setText(newText);
+            break;
+    }
 }
 
 void INDI_E::buildBLOB(IBLOB *ibp)
@@ -382,27 +372,26 @@ void INDI_E::buildBLOB(IBLOB *ibp)
 
     switch (dataProp->getPermission())
     {
-    case IP_RW:
-        setupElementRead(ELEMENT_READ_WIDTH);
-        setupElementWrite(ELEMENT_WRITE_WIDTH);
-        setupBrowseButton();
-        break;
+        case IP_RW:
+            setupElementRead(ELEMENT_READ_WIDTH);
+            setupElementWrite(ELEMENT_WRITE_WIDTH);
+            setupBrowseButton();
+            break;
 
-    case IP_RO:
-        setupElementRead(ELEMENT_FULL_WIDTH);
-        break;
+        case IP_RO:
+            setupElementRead(ELEMENT_FULL_WIDTH);
+            break;
 
-    case IP_WO:
-        setupElementWrite(ELEMENT_FULL_WIDTH);
-        setupBrowseButton();
-        break;
+        case IP_WO:
+            setupElementWrite(ELEMENT_FULL_WIDTH);
+            setupBrowseButton();
+            break;
     }
 
     guiProp->addLayout(EHBox);
-
 }
 
-void INDI_E::buildNumber  (INumber *inp)
+void INDI_E::buildNumber(INumber *inp)
 {
     bool scale = false;
     char iNumber[MAXINDIFORMAT];
@@ -426,37 +415,36 @@ void INDI_E::buildNumber  (INumber *inp)
 
     setupElementLabel();
 
-    if (np->step != 0 && (np->max - np->min)/np->step <= 100)
+    if (np->step != 0 && (np->max - np->min) / np->step <= 100)
         scale = true;
 
     switch (dataProp->getPermission())
     {
-    case IP_RW:
-        setupElementRead(ELEMENT_READ_WIDTH);
-        if (scale)
-            setupElementScale(ELEMENT_WRITE_WIDTH);
-        else
-            setupElementWrite(ELEMENT_WRITE_WIDTH);
+        case IP_RW:
+            setupElementRead(ELEMENT_READ_WIDTH);
+            if (scale)
+                setupElementScale(ELEMENT_WRITE_WIDTH);
+            else
+                setupElementWrite(ELEMENT_WRITE_WIDTH);
 
-        guiProp->addLayout(EHBox);
-        break;
+            guiProp->addLayout(EHBox);
+            break;
 
-    case IP_RO:
-        setupElementRead(ELEMENT_READ_WIDTH);
-        guiProp->addLayout(EHBox);
-        break;
+        case IP_RO:
+            setupElementRead(ELEMENT_READ_WIDTH);
+            guiProp->addLayout(EHBox);
+            break;
 
-    case IP_WO:
-        if (scale)
-            setupElementScale(ELEMENT_FULL_WIDTH);
-        else
-            setupElementWrite(ELEMENT_FULL_WIDTH);
+        case IP_WO:
+            if (scale)
+                setupElementScale(ELEMENT_FULL_WIDTH);
+            else
+                setupElementWrite(ELEMENT_FULL_WIDTH);
 
-        guiProp->addLayout(EHBox);
+            guiProp->addLayout(EHBox);
 
-        break;
+            break;
     }
-
 }
 
 void INDI_E::buildLight(ILight *ilp)
@@ -475,9 +463,9 @@ void INDI_E::buildLight(ILight *ilp)
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = ilp->name;
 
-    led_w = new KLed (guiProp->getGroup()->getContainer());
-    led_w->setMaximumSize(16,16);
-    led_w->setLook( KLed::Sunken );
+    led_w = new KLed(guiProp->getGroup()->getContainer());
+    led_w->setMaximumSize(16, 16);
+    led_w->setLook(KLed::Sunken);
 
     syncLight();
 
@@ -486,93 +474,82 @@ void INDI_E::buildLight(ILight *ilp)
     setupElementLabel();
 
     guiProp->addLayout(EHBox);
-
 }
 
 void INDI_E::syncLight()
 {
-    if (lp == NULL)
+    if (lp == nullptr)
         return;
 
     switch (lp->s)
     {
-    case IPS_IDLE:
-        led_w->setColor(Qt::gray);
-        break;
+        case IPS_IDLE:
+            led_w->setColor(Qt::gray);
+            break;
 
-    case IPS_OK:
-        led_w->setColor(Qt::green);
-        break;
+        case IPS_OK:
+            led_w->setColor(Qt::green);
+            break;
 
-    case IPS_BUSY:
-        led_w->setColor(Qt::yellow);
-        break;
+        case IPS_BUSY:
+            led_w->setColor(Qt::yellow);
+            break;
 
-    case IPS_ALERT:
-        led_w->setColor(Qt::red);
-        break;
-
-    default:
-        break;
+        case IPS_ALERT:
+            led_w->setColor(Qt::red);
+            break;
 
+        default:
+            break;
     }
 }
 
 void INDI_E::setupElementScale(int length)
 {
-
-    if (np == NULL)
+    if (np == nullptr)
         return;
 
-    int steps = (int) ((np->max - np->min) / np->step);
+    int steps = (int)((np->max - np->min) / np->step);
     spin_w    = new QDoubleSpinBox(guiProp->getGroup()->getContainer());
     spin_w->setRange(np->min, np->max);
     spin_w->setSingleStep(np->step);
     spin_w->setValue(np->value);
     spin_w->setDecimals(3);
 
-    slider_w  = new QSlider( Qt::Horizontal, guiProp->getGroup()->getContainer() );
+    slider_w = new QSlider(Qt::Horizontal, guiProp->getGroup()->getContainer());
     slider_w->setRange(0, steps);
     slider_w->setPageStep(1);
-    slider_w->setValue((int) ((np->value - np->min) / np->step));
-
-    connect(spin_w, SIGNAL(valueChanged(double)), this, SLOT(spinChanged(double )));
-    connect(slider_w, SIGNAL(sliderMoved(int)), this, SLOT(sliderChanged(int )));
+    slider_w->setValue((int)((np->value - np->min) / np->step));
 
+    connect(spin_w, SIGNAL(valueChanged(double)), this, SLOT(spinChanged(double)));
+    connect(slider_w, SIGNAL(sliderMoved(int)), this, SLOT(sliderChanged(int)));
 
     if (length == ELEMENT_FULL_WIDTH)
         spin_w->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
     else
         spin_w->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 
-    spin_w->setMinimumWidth( (int) (length * 0.45) );
-    slider_w->setMinimumWidth( (int) (length * 0.55) );
+    spin_w->setMinimumWidth((int)(length * 0.45));
+    slider_w->setMinimumWidth((int)(length * 0.55));
 
     EHBox->addWidget(slider_w);
     EHBox->addWidget(spin_w);
-
 }
 
 void INDI_E::spinChanged(double value)
 {
-
-    int slider_value = (int) ((value - np->min) / np->step);
+    int slider_value = (int)((value - np->min) / np->step);
     slider_w->setValue(slider_value);
-
 }
 
 void INDI_E::sliderChanged(int value)
 {
-
     double spin_value = (value * np->step) + np->min;
     spin_w->setValue(spin_value);
-
-
 }
 
-void INDI_E::setMin ()
+void INDI_E::setMin()
 {
-
     if (spin_w)
     {
         spin_w->setMinimum(np->min);
@@ -580,15 +557,14 @@ void INDI_E::setMin ()
     }
     if (slider_w)
     {
-        slider_w->setMaximum((int) ((np->max - np->min) / np->step));
+        slider_w->setMaximum((int)((np->max - np->min) / np->step));
         slider_w->setMinimum(0);
         slider_w->setPageStep(1);
-        slider_w->setValue( (int) ((np->value - np->min) / np->step ));
+        slider_w->setValue((int)((np->value - np->min) / np->step));
     }
-
 }
 
-void INDI_E::setMax ()
+void INDI_E::setMax()
 {
     if (spin_w)
     {
@@ -597,45 +573,38 @@ void INDI_E::setMax ()
     }
     if (slider_w)
     {
-        slider_w->setMaximum((int) ((np->max - np->min) / np->step));
+        slider_w->setMaximum((int)((np->max - np->min) / np->step));
         slider_w->setMinimum(0);
         slider_w->setPageStep(1);
-        slider_w->setValue( (int) ((np->value - np->min) / np->step ));
+        slider_w->setValue((int)((np->value - np->min) / np->step));
     }
 }
 
 void INDI_E::setupElementWrite(int length)
 {
-
-    write_w = new QLineEdit( guiProp->getGroup()->getContainer());
-    write_w->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred);
-    write_w->setMinimumWidth( length );
-    write_w->setMaximumWidth( length);
+    write_w = new QLineEdit(guiProp->getGroup()->getContainer());
+    write_w->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+    write_w->setMinimumWidth(length);
+    write_w->setMaximumWidth(length);
 
     write_w->setText(text);
 
     //QObject::connect(write_w, SIGNAL(returnPressed(QString)), this, SLOT(updateTP()));
     QObject::connect(write_w, SIGNAL(returnPressed()), guiProp, SLOT(sendText()));
     EHBox->addWidget(write_w);
-
 }
 
-
 void INDI_E::setupElementRead(int length)
 {
-
-
-    read_w = new QLineEdit( guiProp->getGroup()->getContainer() );
-    read_w->setMinimumWidth( length );
-    read_w->setFocusPolicy( Qt::NoFocus );
-    read_w->setCursorPosition( 0 );
-    read_w->setAlignment( Qt::AlignCenter );
-    read_w->setReadOnly( true );
+    read_w = new QLineEdit(guiProp->getGroup()->getContainer());
+    read_w->setMinimumWidth(length);
+    read_w->setFocusPolicy(Qt::NoFocus);
+    read_w->setCursorPosition(0);
+    read_w->setAlignment(Qt::AlignCenter);
+    read_w->setReadOnly(true);
     read_w->setText(text);
 
     EHBox->addWidget(read_w);
-
-
 }
 
 void INDI_E::setupBrowseButton()
@@ -643,20 +612,19 @@ void INDI_E::setupBrowseButton()
     browse_w = new QPushButton(guiProp->getGroup()->getContainer());
     browse_w->setIcon(QIcon::fromTheme("document-open", QIcon(":/icons/breeze/default/document-open.svg")));
     browse_w->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
-    browse_w->setMinimumWidth( MIN_SET_WIDTH );
-    browse_w->setMaximumWidth( MAX_SET_WIDTH );
+    browse_w->setMinimumWidth(MIN_SET_WIDTH);
+    browse_w->setMaximumWidth(MAX_SET_WIDTH);
 
     EHBox->addWidget(browse_w);
     QObject::connect(browse_w, SIGNAL(clicked()), this, SLOT(browseBlob()));
 }
 
-
 void INDI_E::browseBlob()
 {
     QFile fp;
     QString filename;
     QString format;
-    int pos=0;
+    int pos = 0;
     QUrl currentURL;
 
     currentURL = QFileDialog::getOpenFileUrl();
@@ -665,13 +633,13 @@ void INDI_E::browseBlob()
     if (currentURL.isEmpty())
         return;
 
-    if ( currentURL.isValid() )
+    if (currentURL.isValid())
         write_w->setText(currentURL.toLocalFile());
 
     fp.setFileName(currentURL.toLocalFile());
 
-    if ( (pos = filename.lastIndexOf(".")) != -1)
-        format = filename.mid (pos, filename.length());
+    if ((pos = filename.lastIndexOf(".")) != -1)
+        format = filename.mid(pos, filename.length());
 
     //qDebug() << "Filename is " << fp.fileName() << endl;
 
@@ -683,8 +651,8 @@ void INDI_E::browseBlob()
 
     bp->bloblen = bp->size = fp.size();
 
-    bp->blob = (uint8_t *) realloc (bp->blob, bp->size);
-    if (bp->blob == NULL)
+    bp->blob = (uint8_t *)realloc(bp->blob, bp->size);
+    if (bp->blob == nullptr)
     {
         KMessageBox::error(0, i18n("Not enough memory for file %1", filename));
         fp.close();
@@ -693,7 +661,6 @@ void INDI_E::browseBlob()
     memcpy(bp->blob, fp.readAll().constData(), bp->size);
 
     blobDirty = true;
-
 }
 
 QString INDI_E::getWriteField()
@@ -701,7 +668,7 @@ QString INDI_E::getWriteField()
     if (write_w)
         return write_w->text();
     else
-        return NULL;
+        return nullptr;
 }
 
 QString INDI_E::getReadField()
@@ -709,7 +676,5 @@ QString INDI_E::getReadField()
     if (read_w)
         return read_w->text();
     else
-        return NULL;
+        return nullptr;
 }
-
-
