@@ -46,7 +46,7 @@
 
 #include <stdlib.h>
 #include <assert.h>
- 
+
 extern const char *libindi_strings_context;
 
 /*******************************************************************
@@ -54,67 +54,62 @@ extern const char *libindi_strings_context;
 *******************************************************************/
 INDI_P::INDI_P(INDI_G *ipg, INDI::Property *prop)
 {
-    pg = ipg;
+    pg       = ipg;
     dataProp = prop;
 
     name = QString(prop->getName());
 
-    PHBox           = new QHBoxLayout();
+    PHBox = new QHBoxLayout();
     PHBox->setMargin(0);
-    PVBox           = new QVBoxLayout();
+    PVBox = new QVBoxLayout();
     PVBox->setMargin(0);
 
-    ledStatus      = NULL;
-    labelW         = NULL;
-    setB           = NULL;
-    menuC          = NULL;
-    groupB         = NULL;
+    ledStatus = nullptr;
+    labelW    = nullptr;
+    setB      = nullptr;
+    menuC     = nullptr;
+    groupB    = nullptr;
     initGUI();
 }
 
 void INDI_P::updateStateLED()
 {
-
     /* set state light */
     switch (dataProp->getState())
     {
-    case IPS_IDLE:
-        ledStatus->setColor(Qt::gray);
-        break;
+        case IPS_IDLE:
+            ledStatus->setColor(Qt::gray);
+            break;
 
-    case IPS_OK:
-        ledStatus->setColor(Qt::green);
-        break;
+        case IPS_OK:
+            ledStatus->setColor(Qt::green);
+            break;
 
-    case IPS_BUSY:
-        ledStatus->setColor(Qt::yellow);
-        break;
+        case IPS_BUSY:
+            ledStatus->setColor(Qt::yellow);
+            break;
 
-    case IPS_ALERT:
-        ledStatus->setColor(Qt::red);
-        break;
-
-    default:
-        break;
+        case IPS_ALERT:
+            ledStatus->setColor(Qt::red);
+            break;
 
+        default:
+            break;
     }
-
 }
 
 /* build widgets for property pp using info in root.
  */
-void INDI_P::initGUI ()
+void INDI_P::initGUI()
 {
-
     QString label = i18nc(libindi_strings_context, dataProp->getLabel());
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = dataProp->getLabel();
 
-
     /* add to GUI group */
-    ledStatus = new KLed (pg->getContainer());
-    ledStatus->setMaximumSize(16,16);
+    ledStatus = new KLed(pg->getContainer());
+    ledStatus->setMaximumSize(16, 16);
     ledStatus->setLook(KLed::Sunken);
 
     updateStateLED();
@@ -126,7 +121,7 @@ void INDI_P::initGUI ()
     {
         label = i18nc(libindi_strings_context, name.toUtf8());
         if (label == "(I18N_EMPTY_MESSAGE)")
-            label =  name.toUtf8();
+            label = name.toUtf8();
 
         labelW = new KSqueezedTextLabel(label, pg->getContainer());
     }
@@ -134,10 +129,10 @@ void INDI_P::initGUI ()
         labelW = new KSqueezedTextLabel(label, pg->getContainer());
 
     //labelW->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
-    labelW->setFrameShape( QFrame::StyledPanel );
+    labelW->setFrameShape(QFrame::StyledPanel);
     labelW->setFixedWidth(PROPERTY_LABEL_WIDTH);
-    labelW->setTextFormat( Qt::RichText );
-    labelW->setAlignment(Qt::AlignVCenter | Qt::AlignLeft );
+    labelW->setTextFormat(Qt::RichText);
+    labelW->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
     labelW->setWordWrap(true);
 
     PHBox->addWidget(labelW);
@@ -150,47 +145,47 @@ void INDI_P::initGUI ()
 
     switch (dataProp->getType())
     {
-    case INDI_SWITCH:
-        if (dataProp->getSwitch()->r == ISR_NOFMANY)
-            guiType = PG_RADIO;
-        else if (dataProp->getSwitch()->nsp > 4)
-            guiType = PG_MENU;
-        else
-            guiType = PG_BUTTONS;
+        case INDI_SWITCH:
+            if (dataProp->getSwitch()->r == ISR_NOFMANY)
+                guiType = PG_RADIO;
+            else if (dataProp->getSwitch()->nsp > 4)
+                guiType = PG_MENU;
+            else
+                guiType = PG_BUTTONS;
 
-        if (guiType == PG_MENU)
-            buildMenuGUI();
-        else
-            buildSwitchGUI();
-        break;
+            if (guiType == PG_MENU)
+                buildMenuGUI();
+            else
+                buildSwitchGUI();
+            break;
 
-    case INDI_TEXT:
-        buildTextGUI();
-        break;
+        case INDI_TEXT:
+            buildTextGUI();
+            break;
 
-     case INDI_NUMBER:
-        buildNumberGUI();
-        break;
+        case INDI_NUMBER:
+            buildNumberGUI();
+            break;
 
-     case INDI_LIGHT:
-        buildLightGUI();
-        break;
+        case INDI_LIGHT:
+            buildLightGUI();
+            break;
 
-     case INDI_BLOB:
-        buildBLOBGUI();
-        break;
+        case INDI_BLOB:
+            buildBLOBGUI();
+            break;
 
-    default:
-        break;
+        default:
+            break;
     }
 }
 
 void INDI_P::buildSwitchGUI()
 {
-    INDI_E *lp;
+    INDI_E *lp                 = nullptr;
     ISwitchVectorProperty *svp = dataProp->getSwitch();
 
-    if (svp == NULL)
+    if (svp == nullptr)
         return;
 
     groupB = new QButtonGroup(0);
@@ -206,136 +201,125 @@ void INDI_P::buildSwitchGUI()
         groupB->setExclusive(false);
 
     if (svp->p != IP_RO)
-        QObject::connect(groupB, SIGNAL(buttonClicked(QAbstractButton*)), this, SLOT(newSwitch(QAbstractButton *)));
+        QObject::connect(groupB, SIGNAL(buttonClicked(QAbstractButton *)), this, SLOT(newSwitch(QAbstractButton *)));
 
-    for (int i=0; i < svp->nsp; i++)
+    for (int i = 0; i < svp->nsp; i++)
     {
         ISwitch *sp = &(svp->sp[i]);
-        lp = new INDI_E(this, dataProp);
+        lp          = new INDI_E(this, dataProp);
 
         lp->buildSwitch(groupB, sp);
 
         elementList.append(lp);
     }
 
-    horSpacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+    horSpacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 
     PHBox->addItem(horSpacer);
-
 }
 
 void INDI_P::buildTextGUI()
 {
-    INDI_E *lp;
+    INDI_E *lp               = nullptr;
     ITextVectorProperty *tvp = dataProp->getText();
 
-    if (tvp == NULL)
+    if (tvp == nullptr)
         return;
 
-    for (int i=0; i < tvp->ntp; i++)
+    for (int i = 0; i < tvp->ntp; i++)
     {
         IText *tp = &(tvp->tp[i]);
-        lp = new INDI_E(this, dataProp);
+        lp        = new INDI_E(this, dataProp);
 
         lp->buildText(tp);
 
         elementList.append(lp);
     }
 
-
-    horSpacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+    horSpacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 
     PHBox->addItem(horSpacer);
 
-
     if (tvp->p == IP_RO)
-      return;
+        return;
 
     // INDI STD, but we use our own controls
     if (name == "TIME_UTC")
         setupSetButton(i18n("Time"));
-     else
+    else
         setupSetButton(i18n("Set"));
-
 }
 
 void INDI_P::buildNumberGUI()
 {
-
-    INDI_E *lp;
+    INDI_E *lp                 = nullptr;
     INumberVectorProperty *nvp = dataProp->getNumber();
 
-    if (nvp == NULL)
+    if (nvp == nullptr)
         return;
 
-    for (int i=0; i < nvp->nnp; i++)
+    for (int i = 0; i < nvp->nnp; i++)
     {
         INumber *np = &(nvp->np[i]);
-        lp = new INDI_E(this, dataProp);
+        lp          = new INDI_E(this, dataProp);
 
         lp->buildNumber(np);
 
         elementList.append(lp);
     }
 
-
-    horSpacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+    horSpacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 
     PHBox->addItem(horSpacer);
 
-
     if (nvp->p == IP_RO)
-      return;
+        return;
 
     setupSetButton(i18n("Set"));
-
 }
 
 void INDI_P::buildLightGUI()
 {
-
-    INDI_E *ep;
+    INDI_E *ep                = nullptr;
     ILightVectorProperty *lvp = dataProp->getLight();
 
-    if (lvp == NULL)
+    if (lvp == nullptr)
         return;
 
-    for (int i=0; i < lvp->nlp; i++)
+    for (int i = 0; i < lvp->nlp; i++)
     {
         ILight *lp = &(lvp->lp[i]);
-        ep = new INDI_E(this, dataProp);
+        ep         = new INDI_E(this, dataProp);
 
         ep->buildLight(lp);
 
         elementList.append(ep);
     }
 
-
-    horSpacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+    horSpacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 
     PHBox->addItem(horSpacer);
 }
+
 void INDI_P::buildBLOBGUI()
 {
-
-    INDI_E *lp;
+    INDI_E *lp               = nullptr;
     IBLOBVectorProperty *bvp = dataProp->getBLOB();
 
-    if (bvp == NULL)
+    if (bvp == nullptr)
         return;
 
-    for (int i=0; i < bvp->nbp; i++)
+    for (int i = 0; i < bvp->nbp; i++)
     {
         IBLOB *bp = &(bvp->bp[i]);
-        lp = new INDI_E(this, dataProp);
+        lp        = new INDI_E(this, dataProp);
 
         lp->buildBLOB(bp);
 
         elementList.append(lp);
     }
 
-
-    horSpacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+    horSpacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 
     PHBox->addItem(horSpacer);
 
@@ -350,7 +334,6 @@ void INDI_P::buildBLOBGUI()
 
     if (dataProp->getPermission() != IP_RO)
         setupSetButton(i18n("Upload"));
-
 }
 
 void INDI_P::setBLOBOption(int state)
@@ -361,31 +344,31 @@ void INDI_P::setBLOBOption(int state)
         pg->getDevice()->getClientManager()->setBLOBMode(B_NEVER, dataProp->getDeviceName(), dataProp->getName());
 }
 
-
-void INDI_P::newSwitch(QAbstractButton * button)
+void INDI_P::newSwitch(QAbstractButton *button)
 {
     ISwitchVectorProperty *svp = dataProp->getSwitch();
-    QString buttonText = button->text();
+    QString buttonText         = button->text();
 
-    if (svp == NULL)
+    if (svp == nullptr)
         return;
 
     buttonText.remove("&");
 
-    foreach(INDI_E *el, elementList)
+    foreach (INDI_E *el, elementList)
+    {
         if (el->getLabel() == buttonText)
-         {
+        {
             newSwitch(el->getName());
             return;
         }
-
+    }
 }
 
 void INDI_P::resetSwitch()
 {
     ISwitchVectorProperty *svp = dataProp->getSwitch();
 
-    if (svp == NULL)
+    if (svp == nullptr)
         return;
 
     if (menuC)
@@ -398,7 +381,7 @@ void INDI_P::newSwitch(int index)
 {
     ISwitchVectorProperty *svp = dataProp->getSwitch();
 
-    if (svp == NULL)
+    if (svp == nullptr)
         return;
 
     if (index >= svp->nsp)
@@ -412,23 +395,22 @@ void INDI_P::newSwitch(int index)
     sendSwitch();
 }
 
-void INDI_P::newSwitch(const QString & name)
+void INDI_P::newSwitch(const QString &name)
 {
-
     ISwitchVectorProperty *svp = dataProp->getSwitch();
 
-    if (svp == NULL)
+    if (svp == nullptr)
         return;
 
     ISwitch *sp = IUFindSwitch(svp, name.toLatin1().constData());
 
-    if (sp == NULL)
+    if (sp == nullptr)
         return;
 
     if (svp->r == ISR_1OFMANY)
     {
         IUResetSwitch(svp);
-        sp->s  = ISS_ON;
+        sp->s = ISS_ON;
     }
     else
     {
@@ -443,80 +425,75 @@ void INDI_P::newSwitch(const QString & name)
     }
 
     sendSwitch();
-
 }
 
-
 void INDI_P::sendSwitch()
 {
     ISwitchVectorProperty *svp = dataProp->getSwitch();
-    if (svp == NULL)
+
+    if (svp == nullptr)
         return;
 
     svp->s = IPS_BUSY;
 
-    foreach(INDI_E *el, elementList)
+    foreach (INDI_E *el, elementList)
         el->syncSwitch();
 
     updateStateLED();
 
     // Send it to server
     pg->getDevice()->getClientManager()->sendNewSwitch(svp);
-
 }
 
 void INDI_P::sendText()
 {
-    ITextVectorProperty   *tvp = NULL;
-    INumberVectorProperty *nvp = NULL;
+    ITextVectorProperty *tvp   = nullptr;
+    INumberVectorProperty *nvp = nullptr;
 
     switch (dataProp->getType())
     {
         case INDI_TEXT:
             tvp = dataProp->getText();
-            if (tvp == NULL)
+            if (tvp == nullptr)
                 return;
 
             tvp->s = IPS_BUSY;
 
-            foreach(INDI_E *el, elementList)
+            foreach (INDI_E *el, elementList)
                 el->updateTP();
 
             pg->getDevice()->getClientManager()->sendNewText(tvp);
 
-        break;
+            break;
 
-       case INDI_NUMBER:
-        nvp = dataProp->getNumber();
-        if (nvp == NULL)
-            return;
+        case INDI_NUMBER:
+            nvp = dataProp->getNumber();
+            if (nvp == nullptr)
+                return;
 
-        nvp->s = IPS_BUSY;
+            nvp->s = IPS_BUSY;
 
-        foreach(INDI_E *el, elementList)
-            el->updateNP();
+            foreach (INDI_E *el, elementList)
+                el->updateNP();
 
-        pg->getDevice()->getClientManager()->sendNewNumber(nvp);
-
-    default:
-        break;
+            pg->getDevice()->getClientManager()->sendNewNumber(nvp);
 
+        default:
+            break;
     }
 
-
     updateStateLED();
-
 }
 
 void INDI_P::buildMenuGUI()
 {
     QStringList menuOptions;
     QString oneOption;
-    int onItem=-1;
-    INDI_E *lp;
+    int onItem                 = -1;
+    INDI_E *lp                 = nullptr;
     ISwitchVectorProperty *svp = dataProp->getSwitch();
 
-    if (svp == NULL)
+    if (svp == nullptr)
         return;
 
     menuC = new QComboBox(pg->getContainer());
@@ -526,7 +503,7 @@ void INDI_P::buildMenuGUI()
     else
         QObject::connect(menuC, SIGNAL(activated(int)), this, SLOT(newSwitch(int)));
 
-    for (int i=0; i < svp->nsp; i++)
+    for (int i = 0; i < svp->nsp; i++)
     {
         ISwitch *tp = &(svp->sp[i]);
 
@@ -540,7 +517,7 @@ void INDI_P::buildMenuGUI()
         oneOption = i18nc(libindi_strings_context, lp->getLabel().toUtf8());
 
         if (oneOption == "(I18N_EMPTY_MESSAGE)")
-            oneOption =  lp->getLabel().toUtf8();
+            oneOption = lp->getLabel().toUtf8();
 
         menuOptions.append(oneOption);
 
@@ -550,21 +527,18 @@ void INDI_P::buildMenuGUI()
     menuC->addItems(menuOptions);
     menuC->setCurrentIndex(onItem);
 
-    horSpacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
-
+    horSpacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 
     PHBox->addWidget(menuC);
     PHBox->addItem(horSpacer);
-
 }
 
-
 void INDI_P::setupSetButton(const QString &caption)
 {
     setB = new QPushButton(caption, pg->getContainer());
     setB->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
-    setB->setMinimumWidth( MIN_SET_WIDTH );
-    setB->setMaximumWidth( MAX_SET_WIDTH );
+    setB->setMinimumWidth(MIN_SET_WIDTH);
+    setB->setMaximumWidth(MAX_SET_WIDTH);
 
     connect(setB, SIGNAL(clicked()), this, SLOT(processSetButton()));
 
@@ -573,18 +547,19 @@ void INDI_P::setupSetButton(const QString &caption)
 
 void INDI_P::addWidget(QWidget *w)
 {
-        PHBox->addWidget(w);
+    PHBox->addWidget(w);
 }
 
 void INDI_P::addLayout(QHBoxLayout *layout)
 {
-        PVBox->addLayout(layout);
+    PVBox->addLayout(layout);
 }
 
 void INDI_P::updateMenuGUI()
 {
     ISwitchVectorProperty *svp = dataProp->getSwitch();
-    if (svp == NULL)
+
+    if (svp == nullptr)
         return;
 
     int currentIndex = IUFindOnSwitchIndex(svp);
@@ -595,26 +570,25 @@ void INDI_P::processSetButton()
 {
     switch (dataProp->getType())
     {
-       case INDI_TEXT:
-        if (!strcmp(dataProp->getName(), "TIME_UTC"))
-            newTime();
-        else
+        case INDI_TEXT:
+            if (!strcmp(dataProp->getName(), "TIME_UTC"))
+                newTime();
+            else
+                sendText();
+
+            break;
+
+        case INDI_NUMBER:
             sendText();
+            break;
 
-        break;
+        case INDI_BLOB:
+            sendBlob();
+            break;
 
-       case INDI_NUMBER:
-        sendText();
-        break;
-
-       case INDI_BLOB:
-        sendBlob();
-        break;
-
-    default:
-        break;
+        default:
+            break;
     }
-
 }
 
 void INDI_P::sendBlob()
@@ -623,21 +597,21 @@ void INDI_P::sendBlob()
     //bool openingTag=false;
     IBLOBVectorProperty *bvp = dataProp->getBLOB();
 
-    if (bvp == NULL)
+    if (bvp == nullptr)
         return;
 
     bvp->s = IPS_BUSY;
 
     pg->getDevice()->getClientManager()->startBlob(bvp->device, bvp->name, timestamp());
 
-    for (int i=0; i < elementList.count(); i++)
+    for (int i = 0; i < elementList.count(); i++)
     {
         IBLOB *bp = &(bvp->bp[i]);
-        #if (INDI_VERSION_MINOR >= 4 && INDI_VERSION_RELEASE >= 2)
+#if (INDI_VERSION_MINOR >= 4 && INDI_VERSION_RELEASE >= 2)
         pg->getDevice()->getClientManager()->sendOneBlob(bp);
-        #else
+#else
         pg->getDevice()->getClientManager()->sendOneBlob(bp->name, bp->size, bp->format, bp->blob);
-        #endif
+#endif
     }
 
     // JM: Why we need dirty here? We should be able to upload multiple time
@@ -667,56 +641,59 @@ void INDI_P::sendBlob()
     //if (openingTag)
     pg->getDevice()->getClientManager()->finishBlob();
 
-   updateStateLED();
-
+    updateStateLED();
 }
 
-
 void INDI_P::newTime()
 {
-    INDI_E * timeEle;
-    INDI_E * offsetEle;
+    INDI_E *timeEle;
+    INDI_E *offsetEle;
 
     timeEle   = getElement("UTC");
     offsetEle = getElement("OFFSET");
-    if (!timeEle || !offsetEle) return;
+    if (!timeEle || !offsetEle)
+        return;
 
-    TimeDialog timedialog ( KStars::Instance()->data()->ut(), KStars::Instance()->data()->geo(), KStars::Instance(), true );
+    TimeDialog timedialog(KStars::Instance()->data()->ut(), KStars::Instance()->data()->geo(), KStars::Instance(),
+                          true);
 
-    if ( timedialog.exec() == QDialog::Accepted )
+    if (timedialog.exec() == QDialog::Accepted)
     {
-        QTime newTime( timedialog.selectedTime() );
-        QDate newDate( timedialog.selectedDate() );
+        QTime newTime(timedialog.selectedTime());
+        QDate newDate(timedialog.selectedDate());
 
         timeEle->setText(QString("%1-%2-%3T%4:%5:%6")
-                         .arg(newDate.year()).arg(newDate.month())
-                         .arg(newDate.day()).arg(newTime.hour())
-                         .arg(newTime.minute()).arg(newTime.second()));
+                             .arg(newDate.year())
+                             .arg(newDate.month())
+                             .arg(newDate.day())
+                             .arg(newTime.hour())
+                             .arg(newTime.minute())
+                             .arg(newTime.second()));
 
         offsetEle->setText(QString().setNum(KStars::Instance()->data()->geo()->TZ(), 'g', 2));
 
         sendText();
-
     }
-    else return;
-
+    else
+        return;
 }
 
-INDI_E * INDI_P::getElement(const QString &elementName)
+INDI_E *INDI_P::getElement(const QString &elementName)
 {
-    foreach(INDI_E *ep, elementList)
+    foreach (INDI_E *ep, elementList)
     {
         if (ep->getName() == elementName)
             return ep;
     }
 
-    return NULL;
+    return nullptr;
 }
 
 /* INDI property desstructor, makes sure everything is "gone" right */
 INDI_P::~INDI_P()
 {
-    while ( ! elementList.isEmpty() ) delete elementList.takeFirst();
+    while (!elementList.isEmpty())
+        delete elementList.takeFirst();
     delete (ledStatus);
     delete (labelW);
     delete (setB);
@@ -724,7 +701,3 @@ INDI_P::~INDI_P()
     delete (groupB);
     delete (menuC);
 }
-
-
-
-
