@@ -9,33 +9,25 @@
     Handle INDI Standard properties.
  */
 
-#include <basedevice.h>
-
-#include <QDebug>
-#include <QImageReader>
-#include <QStatusBar>
-
-#include <KMessageBox>
-
 #include "indistd.h"
-#include "indicommon.h"
+
 #include "clientmanager.h"
 #include "driverinfo.h"
 #include "deviceinfo.h"
-
 #include "imageviewer.h"
-#include "skypoint.h"
 #include "kstars.h"
 #include "kstarsdata.h"
-#include "skymap.h"
 #include "Options.h"
+#include "skymap.h"
 
-const int MAX_FILENAME_LEN = 1024;
+#include <QImageReader>
+#include <QStatusBar>
 
 namespace ISD
 {
-
-GDSetCommand::GDSetCommand(INDI_PROPERTY_TYPE inPropertyType, const QString &inProperty, const QString &inElement, QVariant qValue, QObject *parent) : QObject(parent)
+GDSetCommand::GDSetCommand(INDI_PROPERTY_TYPE inPropertyType, const QString &inProperty, const QString &inElement,
+                           QVariant qValue, QObject *parent)
+    : QObject(parent)
 {
     propType     = inPropertyType;
     indiProperty = inProperty;
@@ -43,38 +35,34 @@ GDSetCommand::GDSetCommand(INDI_PROPERTY_TYPE inPropertyType, const QString &inP
     elementValue = qValue;
 }
 
-
 GenericDevice::GenericDevice(DeviceInfo *idv)
 {
     connected = false;
 
-    Q_ASSERT(idv != NULL);
+    Q_ASSERT(idv != nullptr);
 
-    deviceInfo        = idv;
-    driverInfo        = idv->getDriverInfo();
-    baseDevice        = idv->getBaseDevice();
-    clientManager     = driverInfo->getClientManager();
+    deviceInfo    = idv;
+    driverInfo    = idv->getDriverInfo();
+    baseDevice    = idv->getBaseDevice();
+    clientManager = driverInfo->getClientManager();
 
-    watchDogTimer     = NULL;
+    watchDogTimer = nullptr;
 
-    dType         = KSTARS_UNKNOWN;
+    dType = KSTARS_UNKNOWN;
 }
 
-
 GenericDevice::~GenericDevice()
 {
-
 }
 
-const char * GenericDevice::getDeviceName()
+const char *GenericDevice::getDeviceName()
 {
     return baseDevice->getDeviceName();
 }
 
 void GenericDevice::registerProperty(INDI::Property *prop)
 {
-
-    foreach(INDI::Property *pp, properties)
+    foreach (INDI::Property *pp, properties)
     {
         if (pp == prop)
             return;
@@ -88,13 +76,20 @@ void GenericDevice::registerProperty(INDI::Property *prop)
     if (!strcmp(prop->getName(), "CONNECTION"))
     {
         ISwitchVectorProperty *svp = prop->getSwitch();
-        if (svp == NULL)
-            return;
-        ISwitch *conSP = IUFindSwitch(svp, "CONNECT");
-        if (conSP == NULL)
+
+        if (svp == nullptr)
             return;
 
-        if (conSP->s == ISS_ON)
+        // Still connecting/disconnecting...
+        if (svp->s == IPS_BUSY)
+            return;
+
+        ISwitch *conSP = IUFindSwitch(svp, "CONNECT");
+
+        if (conSP == nullptr)
+            return;
+
+        if (svp->s == IPS_OK && conSP->s == ISS_ON)
         {
             connected = true;
             emit Connected();
@@ -104,22 +99,23 @@ void GenericDevice::registerProperty(INDI::Property *prop)
 
     if (!strcmp(prop->getName(), "TIME_UTC") && Options::useTimeUpdate() && Options::useComputerSource())
     {
-           ITextVectorProperty *tvp = prop->getText();
-            if (tvp && tvp->p != IP_RO)
-                updateTime();
+        ITextVectorProperty *tvp = prop->getText();
+        if (tvp && tvp->p != IP_RO)
+            updateTime();
     }
-    else if (!strcmp(prop->getName(), "GEOGRAPHIC_COORD") && Options::useGeographicUpdate() && Options::useComputerSource())
+    else if (!strcmp(prop->getName(), "GEOGRAPHIC_COORD") && Options::useGeographicUpdate() &&
+             Options::useComputerSource())
     {
-            INumberVectorProperty *nvp = prop->getNumber();
-            if (nvp && nvp->p != IP_RO)
-                updateLocation();
+        INumberVectorProperty *nvp = prop->getNumber();
+        if (nvp && nvp->p != IP_RO)
+            updateLocation();
     }
     else if (!strcmp(prop->getName(), "WATCHDOG_HEARTBEAT"))
     {
         INumberVectorProperty *nvp = prop->getNumber();
         if (nvp)
         {
-            if (watchDogTimer == NULL)
+            if (watchDogTimer == nullptr)
             {
                 watchDogTimer = new QTimer(this);
                 connect(watchDogTimer, SIGNAL(timeout()), this, SLOT(resetWatchdog()));
@@ -138,24 +134,30 @@ void GenericDevice::registerProperty(INDI::Property *prop)
 void GenericDevice::removeProperty(INDI::Property *prop)
 {
     properties.removeOne(prop);
+
+    emit propertyDeleted(prop);
 }
 
-void GenericDevice::processSwitch(ISwitchVectorProperty * svp)
+void GenericDevice::processSwitch(ISwitchVectorProperty *svp)
 {
-
     if (!strcmp(svp->name, "CONNECTION"))
     {
         ISwitch *conSP = IUFindSwitch(svp, "CONNECT");
-        if (conSP == NULL)
+
+        if (conSP == nullptr)
             return;
 
-        if (conSP->s == ISS_ON)
+        // Still connecting/disconnecting...
+        if (svp->s == IPS_BUSY)
+            return;
+
+        if (svp->s == IPS_OK && conSP->s == ISS_ON)
         {
             connected = true;
             emit Connected();
             createDeviceInit();
 
-            if (watchDogTimer != NULL)
+            if (watchDogTimer != nullptr)
             {
                 INumberVectorProperty *nvp = baseDevice->getNumber("WATCHDOG_HEARTBEAT");
                 if (nvp && nvp->np[0].value > 0)
@@ -173,16 +175,16 @@ void GenericDevice::processSwitch(ISwitchVectorProperty * svp)
         }
     }
 
-
+    emit switchUpdated(svp);
 }
 
-void GenericDevice::processNumber(INumberVectorProperty * nvp)
+void GenericDevice::processNumber(INumberVectorProperty *nvp)
 {
     if (Options::useDeviceSource() && !strcmp(nvp->name, "GEOGRAPHIC_COORD") && nvp->s == IPS_OK)
     {
         // Update KStars Location once we receive update from INDI, if the source is set to DEVICE
         dms lng, lat;
-        INumber *np=NULL;
+        INumber *np = nullptr;
 
         np = IUFindNumber(nvp, "LONG");
         if (!np)
@@ -192,7 +194,7 @@ void GenericDevice::processNumber(INumberVectorProperty * nvp)
         if (np->value < 180)
             lng.setD(np->value);
         else
-            lng.setD(np->value-360.0);
+            lng.setD(np->value - 360.0);
 
         np = IUFindNumber(nvp, "LAT");
         if (!np)
@@ -208,7 +210,7 @@ void GenericDevice::processNumber(INumberVectorProperty * nvp)
     }
     else if (!strcmp(nvp->name, "WATCHDOG_HEARTBEAT"))
     {
-        if (watchDogTimer == NULL)
+        if (watchDogTimer == nullptr)
         {
             watchDogTimer = new QTimer(this);
             connect(watchDogTimer, SIGNAL(timeout()), this, SLOT(resetWatchdog()));
@@ -217,20 +219,21 @@ void GenericDevice::processNumber(INumberVectorProperty * nvp)
         if (connected && nvp->np[0].value > 0)
         {
             // Reset timer 15 seconds before it is due
-            watchDogTimer->start(nvp->np[0].value*60*1000 - 15*1000);
+            watchDogTimer->start(nvp->np[0].value * 60 * 1000 - 15 * 1000);
         }
         else if (nvp->np[0].value == 0)
             watchDogTimer->stop();
     }
+
+    emit numberUpdated(nvp);
 }
 
-void GenericDevice::processText(ITextVectorProperty * tvp)
-{    
-
+void GenericDevice::processText(ITextVectorProperty *tvp)
+{
     // Update KStars time once we receive update from INDI, if the source is set to DEVICE
     if (Options::useDeviceSource() && !strcmp(tvp->name, "TIME_UTC") && tvp->s == IPS_OK)
     {
-        IText *tp=NULL;
+        IText *tp = nullptr;
         int d, m, y, min, sec, hour;
         float utcOffset;
         QDate indiDate;
@@ -259,156 +262,159 @@ void GenericDevice::processText(ITextVectorProperty * tvp)
         KStars::Instance()->data()->syncLST();
 
         GeoLocation *geo = KStars::Instance()->data()->geo();
-        geo->setTZ(utcOffset);    
-
+        geo->setTZ(utcOffset);
     }
+
+    emit textUpdated(tvp);
 }
 
-void GenericDevice::processLight(ILightVectorProperty * lvp)
+void GenericDevice::processLight(ILightVectorProperty *lvp)
 {
-    INDI_UNUSED(lvp);
+    emit lightUpdated(lvp);
 }
 
 void GenericDevice::processMessage(int messageID)
 {
-   INDI_UNUSED(messageID);
+    emit messageUpdated(messageID);
 }
 
-void GenericDevice::processBLOB(IBLOB* bp)
+void GenericDevice::processBLOB(IBLOB *bp)
 {
-    QFile       *data_file = NULL;
+    // Ignore write-only BLOBs since we only receive it for state-change
+    if (bp->bvp->p == IP_WO)
+        return;
+
+    QFile *data_file = nullptr;
     INDIDataTypes dataType;
 
-   if (!strcmp(bp->format, ".ascii"))
+    if (!strcmp(bp->format, ".ascii"))
         dataType = DATA_ASCII;
     else
         dataType = DATA_OTHER;
 
     QString currentDir = Options::fitsDir();
-    int nr, n=0;
+    int nr, n = 0;
 
     if (currentDir.endsWith('/'))
-        currentDir.truncate(sizeof(currentDir)-1);
+        currentDir.truncate(sizeof(currentDir) - 1);
 
     QString filename(currentDir + '/');
 
-    QString ts = QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss");
+    QString ts = QDateTime::currentDateTime().toString("yyyy-MM-ddThh-mm-ss");
 
-    filename += QString("file_") + ts +  QString(bp->format).trimmed();
+    filename += QString("file_") + ts + QString(bp->format).trimmed();
 
     strncpy(BLOBFilename, filename.toLatin1(), MAXINDIFILENAME);
     bp->aux2 = BLOBFilename;
 
     if (dataType == DATA_ASCII)
     {
-        if (bp->aux0 == NULL)
+        if (bp->aux0 == nullptr)
         {
-            bp->aux0 = new int();
-            QFile * ascii_data_file = new QFile();
+            bp->aux0               = new int();
+            QFile *ascii_data_file = new QFile();
             ascii_data_file->setFileName(filename);
             if (!ascii_data_file->open(QIODevice::WriteOnly))
             {
-                        qDebug() << "GenericDevice Error: Unable to open " << ascii_data_file->fileName() << endl;
-                        return;
+                qDebug() << "GenericDevice Error: Unable to open " << ascii_data_file->fileName() << endl;
+                return;
             }
 
             bp->aux1 = ascii_data_file;
         }
 
-        data_file = (QFile *) bp->aux1;
+        data_file = (QFile *)bp->aux1;
 
         QDataStream out(data_file);
-        for (nr=0; nr < (int) bp->size; nr += n)
-           n = out.writeRawData( static_cast<char *> (bp->blob) + nr, bp->size - nr);
+        for (nr = 0; nr < (int)bp->size; nr += n)
+            n = out.writeRawData(static_cast<char *>(bp->blob) + nr, bp->size - nr);
 
-        out.writeRawData( (const char *) "\n" , 1);
+        out.writeRawData((const char *)"\n", 1);
         data_file->flush();
-   }
+    }
     else
     {
         QFile fits_temp_file(filename);
         if (!fits_temp_file.open(QIODevice::WriteOnly))
         {
-                qDebug() << "GenericDevice Error: Unable to open " << fits_temp_file.fileName() << endl;
-        return;
+            qDebug() << "GenericDevice Error: Unable to open " << fits_temp_file.fileName() << endl;
+            return;
         }
 
         QDataStream out(&fits_temp_file);
 
-        for (nr=0; nr < (int) bp->size; nr += n)
-            n = out.writeRawData( static_cast<char *> (bp->blob) +nr, bp->size - nr);
+        for (nr = 0; nr < (int)bp->size; nr += n)
+            n = out.writeRawData(static_cast<char *>(bp->blob) + nr, bp->size - nr);
 
         fits_temp_file.close();
 
         QByteArray fmt = QString(bp->format).toLower().remove(".").toUtf8();
         if (QImageReader::supportedImageFormats().contains(fmt))
         {
-            QUrl url (filename);
+            QUrl url(filename);
             url.setScheme("file");
-             ImageViewer *iv = new ImageViewer(url, QString(), KStars::Instance());
-             if (iv)
+            ImageViewer *iv = new ImageViewer(url, QString(), KStars::Instance());
+            if (iv)
                 iv->show();
         }
     }
 
-    if (dataType == DATA_OTHER)      
-        KStars::Instance()->statusBar()->showMessage(i18n("Data file saved to %1", filename ), 0);
+    if (dataType == DATA_OTHER)
+        KStars::Instance()->statusBar()->showMessage(i18n("Data file saved to %1", filename), 0);
 
+    emit BLOBUpdated(bp);
 }
 
 bool GenericDevice::setConfig(INDIConfig tConfig)
 {
-
     ISwitchVectorProperty *svp = baseDevice->getSwitch("CONFIG_PROCESS");
-    if (svp == NULL)
+
+    if (svp == nullptr)
         return false;
 
-    ISwitch *sp = NULL;
+    ISwitch *sp = nullptr;
 
     IUResetSwitch(svp);
 
     switch (tConfig)
     {
         case LOAD_LAST_CONFIG:
-        sp = IUFindSwitch(svp, "CONFIG_LOAD");
-        if (sp == NULL)
-            return false;
+            sp = IUFindSwitch(svp, "CONFIG_LOAD");
+            if (sp == nullptr)
+                return false;
 
-        IUResetSwitch(svp);
-        sp->s = ISS_ON;
-        break;
+            IUResetSwitch(svp);
+            sp->s = ISS_ON;
+            break;
 
         case SAVE_CONFIG:
-        sp = IUFindSwitch(svp, "CONFIG_SAVE");
-        if (sp == NULL)
-            return false;
+            sp = IUFindSwitch(svp, "CONFIG_SAVE");
+            if (sp == nullptr)
+                return false;
 
-        IUResetSwitch(svp);
-        sp->s = ISS_ON;
-        break;
+            IUResetSwitch(svp);
+            sp->s = ISS_ON;
+            break;
 
         case LOAD_DEFAULT_CONFIG:
-        sp = IUFindSwitch(svp, "CONFIG_DEFAULT");
-        if (sp == NULL)
-            return false;
-
-        IUResetSwitch(svp);
-        sp->s = ISS_ON;
-        break;
+            sp = IUFindSwitch(svp, "CONFIG_DEFAULT");
+            if (sp == nullptr)
+                return false;
 
+            IUResetSwitch(svp);
+            sp->s = ISS_ON;
+            break;
     }
 
     clientManager->sendNewSwitch(svp);
 
     return true;
-
 }
 
 void GenericDevice::createDeviceInit()
 {
-
-    if ( Options::showINDIMessages() )
-        KStars::Instance()->statusBar()->showMessage( i18n("%1 is online.", baseDevice->getDeviceName()), 0);
+    if (Options::showINDIMessages())
+        KStars::Instance()->statusBar()->showMessage(i18n("%1 is online.", baseDevice->getDeviceName()), 0);
 
     KStars::Instance()->map()->forceUpdateNow();
 }
@@ -418,22 +424,22 @@ void GenericDevice::createDeviceInit()
 /*********************************************************************************/
 void GenericDevice::updateTime()
 {
-
     QString offset, isoTS;
 
     offset = QString().setNum(KStars::Instance()->data()->geo()->TZ(), 'g', 2);
 
-    QTime newTime( KStars::Instance()->data()->ut().time());
-    QDate newDate( KStars::Instance()->data()->ut().date());
+    //QTime newTime( KStars::Instance()->data()->ut().time());
+    //QDate newDate( KStars::Instance()->data()->ut().date());
 
-    isoTS = QString("%1-%2-%3T%4:%5:%6").arg(newDate.year()).arg(newDate.month()).arg(newDate.day()).arg(newTime.hour()).arg(newTime.minute()).arg(newTime.second());
+    //isoTS = QString("%1-%2-%3T%4:%5:%6").arg(newDate.year()).arg(newDate.month()).arg(newDate.day()).arg(newTime.hour()).arg(newTime.minute()).arg(newTime.second());
+
+    isoTS = KStars::Instance()->data()->ut().toString(Qt::ISODate).remove("Z");
 
     /* Update Date/Time */
     ITextVectorProperty *timeUTC = baseDevice->getText("TIME_UTC");
 
     if (timeUTC)
     {
-
         IText *timeEle = IUFindText(timeUTC, "UTC");
         if (timeEle)
             IUSaveText(timeEle, isoTS.toLatin1().constData());
@@ -462,17 +468,18 @@ void GenericDevice::updateLocation()
 
     INumberVectorProperty *nvp = baseDevice->getNumber("GEOGRAPHIC_COORD");
 
-    if (nvp == NULL)
+    if (nvp == nullptr)
         return;
 
     INumber *np = IUFindNumber(nvp, "LONG");
-    if (np == NULL)
+
+    if (np == nullptr)
         return;
 
     np->value = longNP;
 
     np = IUFindNumber(nvp, "LAT");
-    if (np == NULL)
+    if (np == nullptr)
         return;
 
     np->value = geo->lat()->Degrees();
@@ -482,61 +489,86 @@ void GenericDevice::updateLocation()
 
 bool GenericDevice::Connect()
 {
-    return runCommand(INDI_CONNECT, NULL);
+    return runCommand(INDI_CONNECT, nullptr);
 }
 
 bool GenericDevice::Disconnect()
 {
-    return runCommand(INDI_DISCONNECT, NULL);
+    return runCommand(INDI_DISCONNECT, nullptr);
 }
 
 bool GenericDevice::runCommand(int command, void *ptr)
 {
     switch (command)
     {
-       case INDI_CONNECT:
-        clientManager->connectDevice(baseDevice->getDeviceName());
-        break;
-
-      case INDI_DISCONNECT:
-        clientManager->disconnectDevice(baseDevice->getDeviceName());
-        break;
-
-       case INDI_SET_PORT:
-       {
-        if (ptr == NULL)
-            return false;
-        ITextVectorProperty *tvp = baseDevice->getText("DEVICE_PORT");
-        if (tvp == NULL)
-            return false;
-
-        IText *tp = IUFindText(tvp, "PORT");
-
-        IUSaveText(tp, (static_cast<QString *> (ptr))->toLatin1().constData() );
-
-        clientManager->sendNewText(tvp);
-       }
-        break;
-
-      // We do it here because it could be either CCD or FILTER interfaces, so no need to duplicate code
-      case INDI_SET_FILTER:
-      {
-        if (ptr == NULL)
-            return false;
-        INumberVectorProperty *nvp = baseDevice->getNumber("FILTER_SLOT");
-        if (nvp == NULL)
-            return false;
-
-        int requestedFilter = * ( (int *) ptr);
-
-        if (requestedFilter == nvp->np[0].value)
+        case INDI_CONNECT:
+            clientManager->connectDevice(baseDevice->getDeviceName());
             break;
 
-        nvp->np[0].value  = requestedFilter;
+        case INDI_DISCONNECT:
+            clientManager->disconnectDevice(baseDevice->getDeviceName());
+            break;
 
-        clientManager->sendNewNumber(nvp);
-      }
+        case INDI_SET_PORT:
+        {
+            if (ptr == nullptr)
+                return false;
 
+            ITextVectorProperty *tvp = baseDevice->getText("DEVICE_PORT");
+
+            if (tvp == nullptr)
+                return false;
+
+            IText *tp = IUFindText(tvp, "PORT");
+
+            IUSaveText(tp, (static_cast<QString *>(ptr))->toLatin1().constData());
+
+            clientManager->sendNewText(tvp);
+        }
+        break;
+
+        // We do it here because it could be either CCD or FILTER interfaces, so no need to duplicate code
+        case INDI_SET_FILTER:
+        {
+            if (ptr == nullptr)
+                return false;
+
+            INumberVectorProperty *nvp = baseDevice->getNumber("FILTER_SLOT");
+
+            if (nvp == nullptr)
+                return false;
+
+            int requestedFilter = *((int *)ptr);
+
+            if (requestedFilter == nvp->np[0].value)
+                break;
+
+            nvp->np[0].value = requestedFilter;
+
+            clientManager->sendNewNumber(nvp);
+        }
+        break;
+
+        // We do it here because it could be either FOCUSER or ROTATOR interfaces, so no need to duplicate code
+        case INDI_SET_ROTATOR:
+        {
+            if (ptr == nullptr)
+                return false;
+
+            INumberVectorProperty *nvp = baseDevice->getNumber("ABS_ROTATOR_POSITION");
+
+            if (nvp == nullptr)
+                return false;
+
+            int32_t requestedTicks = *((int32_t *)ptr);
+
+            if (requestedTicks == nvp->np[0].value)
+                break;
+
+            nvp->np[0].value = requestedTicks;
+
+            clientManager->sendNewNumber(nvp);
+        }
         break;
 
     }
@@ -544,87 +576,92 @@ bool GenericDevice::runCommand(int command, void *ptr)
     return true;
 }
 
-bool GenericDevice::setProperty(QObject * setPropCommand)
+bool GenericDevice::setProperty(QObject *setPropCommand)
 {
-    GDSetCommand *indiCommand = static_cast<GDSetCommand *> (setPropCommand);
+    GDSetCommand *indiCommand = static_cast<GDSetCommand *>(setPropCommand);
 
     //qDebug() << "We are trying to set value for property " << indiCommand->indiProperty << " and element" << indiCommand->indiElement << " and value " << indiCommand->elementValue << endl;
 
-    INDI::Property *pp= baseDevice->getProperty(indiCommand->indiProperty.toLatin1().constData());
-    if (pp == NULL)
+    INDI::Property *pp = baseDevice->getProperty(indiCommand->indiProperty.toLatin1().constData());
+
+    if (pp == nullptr)
         return false;
 
     switch (indiCommand->propType)
     {
         case INDI_SWITCH:
         {
-        ISwitchVectorProperty *svp = pp->getSwitch();
-        if (svp == NULL)
-            return false;
+            ISwitchVectorProperty *svp = pp->getSwitch();
 
-        ISwitch *sp = IUFindSwitch(svp, indiCommand->indiElement.toLatin1().constData());
-        if (sp == NULL)
-            return false;
+            if (svp == nullptr)
+                return false;
 
-        if (svp->r == ISR_1OFMANY || svp->r == ISR_ATMOST1)
-            IUResetSwitch(svp);
+            ISwitch *sp = IUFindSwitch(svp, indiCommand->indiElement.toLatin1().constData());
 
-        sp->s = indiCommand->elementValue.toInt() == 0 ? ISS_OFF : ISS_ON;
+            if (sp == nullptr)
+                return false;
 
-        //qDebug() << "Sending switch " << sp->name << " with status " << ((sp->s == ISS_ON) ? "On" : "Off") << endl;
-        clientManager->sendNewSwitch(svp);
+            if (svp->r == ISR_1OFMANY || svp->r == ISR_ATMOST1)
+                IUResetSwitch(svp);
 
-        return true;
-       }
-          break;
+            sp->s = indiCommand->elementValue.toInt() == 0 ? ISS_OFF : ISS_ON;
 
-    case INDI_NUMBER:
-    {
-        INumberVectorProperty *nvp = pp->getNumber();
-        if (nvp == NULL)
-            return false;
+            //qDebug() << "Sending switch " << sp->name << " with status " << ((sp->s == ISS_ON) ? "On" : "Off") << endl;
+            clientManager->sendNewSwitch(svp);
 
-        INumber *np = IUFindNumber(nvp, indiCommand->indiElement.toLatin1().constData());
-        if (np == NULL)
-            return false;
-
-        double value = indiCommand->elementValue.toDouble();
-
-        if (value == np->value)
             return true;
-
-        np->value = value;
-
-      //qDebug() << "Sending switch " << sp->name << " with status " << ((sp->s == ISS_ON) ? "On" : "Off") << endl;
-      clientManager->sendNewNumber(nvp);
-    }
-   break;
-        // TODO: Add set property for other types of properties
-    default:
+        }
         break;
 
+        case INDI_NUMBER:
+        {
+            INumberVectorProperty *nvp = pp->getNumber();
+
+            if (nvp == nullptr)
+                return false;
+
+            INumber *np = IUFindNumber(nvp, indiCommand->indiElement.toLatin1().constData());
+
+            if (np == nullptr)
+                return false;
+
+            double value = indiCommand->elementValue.toDouble();
+
+            if (value == np->value)
+                return true;
+
+            np->value = value;
+
+            //qDebug() << "Sending switch " << sp->name << " with status " << ((sp->s == ISS_ON) ? "On" : "Off") << endl;
+            clientManager->sendNewNumber(nvp);
+        }
+        break;
+        // TODO: Add set property for other types of properties
+        default:
+            break;
     }
 
     return true;
 }
 
-bool GenericDevice::getMinMaxStep(const QString & propName, const QString & elementName, double *min, double *max, double *step)
+bool GenericDevice::getMinMaxStep(const QString &propName, const QString &elementName, double *min, double *max,
+                                  double *step)
 {
     INumberVectorProperty *nvp = baseDevice->getNumber(propName.toLatin1());
 
-    if (nvp == NULL)
+    if (nvp == nullptr)
         return false;
 
     INumber *np = IUFindNumber(nvp, elementName.toLatin1());
-    if (np == NULL)
+
+    if (np == nullptr)
         return false;
 
-    *min = np->min;
-    *max = np->max;
+    *min  = np->min;
+    *max  = np->max;
     *step = np->step;
 
     return true;
-
 }
 
 IPState GenericDevice::getState(const QString &propName)
@@ -642,14 +679,25 @@ void GenericDevice::resetWatchdog()
     INumberVectorProperty *nvp = baseDevice->getNumber("WATCHDOG_HEARTBEAT");
 
     if (nvp)
-       // Send heartbeat to driver
-       clientManager->sendNewNumber(nvp);
+        // Send heartbeat to driver
+        clientManager->sendNewNumber(nvp);
 }
 
 DeviceDecorator::DeviceDecorator(GDInterface *iPtr)
 {
     interfacePtr = iPtr;
 
+    connect(iPtr, SIGNAL(Connected()), this, SIGNAL(Connected()));
+    connect(iPtr, SIGNAL(Disconnected()), this, SIGNAL(Disconnected()));
+    connect(iPtr, SIGNAL(propertyDefined(INDI::Property *)), this, SIGNAL(propertyDefined(INDI::Property *)));
+    connect(iPtr, SIGNAL(propertyDeleted(INDI::Property *)), this, SIGNAL(propertyDeleted(INDI::Property *)));
+    connect(iPtr, SIGNAL(messageUpdated(int)), this, SIGNAL(messageUpdated(int)));
+    connect(iPtr, SIGNAL(switchUpdated(ISwitchVectorProperty *)), this, SIGNAL(switchUpdated(ISwitchVectorProperty *)));
+    connect(iPtr, SIGNAL(numberUpdated(INumberVectorProperty *)), this, SIGNAL(numberUpdated(INumberVectorProperty *)));
+    connect(iPtr, SIGNAL(textUpdated(ITextVectorProperty *)), this, SIGNAL(textUpdated(ITextVectorProperty *)));
+    connect(iPtr, SIGNAL(BLOBUpdated(IBLOB *)), this, SIGNAL(BLOBUpdated(IBLOB *)));
+    connect(iPtr, SIGNAL(lightUpdated(ILightVectorProperty *)), this, SIGNAL(lightUpdated(ILightVectorProperty *)));
+
     baseDevice    = interfacePtr->getBaseDevice();
     clientManager = interfacePtr->getDriverInfo()->getClientManager();
 }
@@ -672,39 +720,31 @@ bool DeviceDecorator::setProperty(QObject *setPropCommand)
 void DeviceDecorator::processBLOB(IBLOB *bp)
 {
     interfacePtr->processBLOB(bp);
-    emit BLOBUpdated(bp);
-
 }
 
 void DeviceDecorator::processLight(ILightVectorProperty *lvp)
 {
     interfacePtr->processLight(lvp);
-    emit lightUpdated(lvp);
-
 }
 
 void DeviceDecorator::processNumber(INumberVectorProperty *nvp)
 {
     interfacePtr->processNumber(nvp);
-    emit numberUpdated(nvp);
 }
 
 void DeviceDecorator::processSwitch(ISwitchVectorProperty *svp)
 {
     interfacePtr->processSwitch(svp);
-    emit switchUpdated(svp);
 }
 
 void DeviceDecorator::processText(ITextVectorProperty *tvp)
 {
     interfacePtr->processText(tvp);
-    emit textUpdated(tvp);
 }
 
 void DeviceDecorator::processMessage(int messageID)
 {
     interfacePtr->processMessage(messageID);
-    emit messageUpdated(messageID);
 }
 
 void DeviceDecorator::registerProperty(INDI::Property *prop)
@@ -715,7 +755,6 @@ void DeviceDecorator::registerProperty(INDI::Property *prop)
 void DeviceDecorator::removeProperty(INDI::Property *prop)
 {
     interfacePtr->removeProperty(prop);
-    emit propertyDeleted(prop);
 }
 
 bool DeviceDecorator::setConfig(INDIConfig tConfig)
@@ -728,22 +767,22 @@ DeviceFamily DeviceDecorator::getType()
     return interfacePtr->getType();
 }
 
-DriverInfo * DeviceDecorator::getDriverInfo()
+DriverInfo *DeviceDecorator::getDriverInfo()
 {
     return interfacePtr->getDriverInfo();
 }
 
-DeviceInfo * DeviceDecorator::getDeviceInfo()
+DeviceInfo *DeviceDecorator::getDeviceInfo()
 {
     return interfacePtr->getDeviceInfo();
 }
 
-const char * DeviceDecorator::getDeviceName()
+const char *DeviceDecorator::getDeviceName()
 {
     return interfacePtr->getDeviceName();
 }
 
-INDI::BaseDevice* DeviceDecorator::getBaseDevice()
+INDI::BaseDevice *DeviceDecorator::getBaseDevice()
 {
     return interfacePtr->getBaseDevice();
 }
@@ -768,12 +807,10 @@ bool DeviceDecorator::Disconnect()
     return interfacePtr->Disconnect();
 }
 
-
-bool DeviceDecorator::getMinMaxStep(const QString & propName, const QString & elementName, double *min, double *max, double *step)
+bool DeviceDecorator::getMinMaxStep(const QString &propName, const QString &elementName, double *min, double *max,
+                                    double *step)
 {
-
     return interfacePtr->getMinMaxStep(propName, elementName, min, max, step);
-
 }
 
 IPState DeviceDecorator::getState(const QString &propName)
@@ -786,17 +823,18 @@ IPerm DeviceDecorator::getPermission(const QString &propName)
     return interfacePtr->getPermission(propName);
 }
 
-
 ST4::ST4(INDI::BaseDevice *bdv, ClientManager *cm)
 {
-    baseDevice = bdv;
+    baseDevice    = bdv;
     clientManager = cm;
-    swapDEC = false;
+    swapDEC       = false;
 }
 
-ST4::~ST4() {}
+ST4::~ST4()
+{
+}
 
-const char * ST4::getDeviceName()
+const char *ST4::getDeviceName()
 {
     return baseDevice->getDeviceName();
 }
@@ -806,9 +844,9 @@ void ST4::setDECSwap(bool enable)
     swapDEC = enable;
 }
 
-bool ST4::doPulse(GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, int dec_msecs )
+bool ST4::doPulse(GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, int dec_msecs)
 {
-    bool raOK=false, decOK=false;
+    bool raOK = false, decOK = false;
     raOK  = doPulse(ra_dir, ra_msecs);
     decOK = doPulse(dec_dir, dec_msecs);
 
@@ -816,17 +854,16 @@ bool ST4::doPulse(GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, i
         return true;
     else
         return false;
-
 }
 
-bool ST4::doPulse(GuideDirection dir, int msecs )
+bool ST4::doPulse(GuideDirection dir, int msecs)
 {
     INumberVectorProperty *raPulse  = baseDevice->getNumber("TELESCOPE_TIMED_GUIDE_WE");
     INumberVectorProperty *decPulse = baseDevice->getNumber("TELESCOPE_TIMED_GUIDE_NS");
-    INumberVectorProperty *npulse = NULL;
-    INumber *dirPulse=NULL;
+    INumberVectorProperty *npulse   = nullptr;
+    INumber *dirPulse               = nullptr;
 
-    if (raPulse == NULL || decPulse == NULL)
+    if (raPulse == nullptr || decPulse == nullptr)
         return false;
 
     if (dir == RA_INC_DIR || dir == RA_DEC_DIR)
@@ -834,52 +871,53 @@ bool ST4::doPulse(GuideDirection dir, int msecs )
     else
         decPulse->np[0].value = decPulse->np[1].value = 0;
 
-    switch(dir)
+    switch (dir)
     {
-    case RA_INC_DIR:
-    dirPulse = IUFindNumber(raPulse, "TIMED_GUIDE_W");
-    if (dirPulse == NULL)
-        return false;
+        case RA_INC_DIR:
+            dirPulse = IUFindNumber(raPulse, "TIMED_GUIDE_W");
+            if (dirPulse == nullptr)
+                return false;
 
-    npulse = raPulse;
-    break;
+            npulse = raPulse;
+            break;
 
-    case RA_DEC_DIR:
-    dirPulse = IUFindNumber(raPulse, "TIMED_GUIDE_E");
-    if (dirPulse == NULL)
-        return false;
+        case RA_DEC_DIR:
+            dirPulse = IUFindNumber(raPulse, "TIMED_GUIDE_E");
+            if (dirPulse == nullptr)
+                return false;
 
-    npulse = raPulse;
-    break;
+            npulse = raPulse;
+            break;
 
-    case DEC_INC_DIR:
-        if (swapDEC)
-            dirPulse = IUFindNumber(decPulse, "TIMED_GUIDE_S");
-        else
-            dirPulse = IUFindNumber(decPulse, "TIMED_GUIDE_N");
-    if (dirPulse == NULL)
-        return false;
+        case DEC_INC_DIR:
+            if (swapDEC)
+                dirPulse = IUFindNumber(decPulse, "TIMED_GUIDE_S");
+            else
+                dirPulse = IUFindNumber(decPulse, "TIMED_GUIDE_N");
 
-    npulse = decPulse;
-    break;
+            if (dirPulse == nullptr)
+                return false;
 
-    case DEC_DEC_DIR:
-        if (swapDEC)
-            dirPulse = IUFindNumber(decPulse, "TIMED_GUIDE_N");
-        else
-            dirPulse = IUFindNumber(decPulse, "TIMED_GUIDE_S");
-    if (dirPulse == NULL)
-        return false;
+            npulse = decPulse;
+            break;
 
-    npulse = decPulse;
-    break;
+        case DEC_DEC_DIR:
+            if (swapDEC)
+                dirPulse = IUFindNumber(decPulse, "TIMED_GUIDE_N");
+            else
+                dirPulse = IUFindNumber(decPulse, "TIMED_GUIDE_S");
 
-    default:
-        return false;
+            if (dirPulse == nullptr)
+                return false;
 
+            npulse = decPulse;
+            break;
+
+        default:
+            return false;
     }
 
-    if (dirPulse == NULL || npulse == NULL)
+    if (dirPulse == nullptr || npulse == nullptr)
         return false;
 
     dirPulse->value = msecs;
@@ -889,9 +927,5 @@ bool ST4::doPulse(GuideDirection dir, int msecs )
     //qDebug() << "Sending pulse for " << npulse->name << " in direction " << dirPulse->name << " for " << msecs << " ms " << endl;
 
     return true;
-
 }
-
 }
-
-
