@@ -5,7 +5,7 @@
     modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation; either
     version 2 of the License, or (at your option) any later version.
-    
+
  */
 
 #include "opsindi.h"
@@ -26,52 +26,54 @@
 
 #include "kstars.h"
 
-OpsINDI::OpsINDI()
-        : QFrame(KStars::Instance())
+OpsINDI::OpsINDI() : QFrame(KStars::Instance())
 {
     setupUi(this);
-    
-    //Get a pointer to the KConfigDialog
-    m_ConfigDialog = KConfigDialog::exists( "settings" );
 
-    selectFITSDirB->setIcon( QIcon::fromTheme( "document-open-folder", QIcon(":/icons/breeze/default/document-open-folder.svg")) );
+    //Get a pointer to the KConfigDialog
+    m_ConfigDialog = KConfigDialog::exists("settings");
+
+    selectFITSDirB->setIcon(
+        QIcon::fromTheme("document-open-folder", QIcon(":/icons/breeze/default/document-open-folder.svg")));
     selectFITSDirB->setAttribute(Qt::WA_LayoutUsesWidgetRect);
-    selectDriversDirB->setIcon( QIcon::fromTheme( "document-open-folder", QIcon(":/icons/breeze/default/document-open-folder.svg")) );
+    selectDriversDirB->setIcon(
+        QIcon::fromTheme("document-open-folder", QIcon(":/icons/breeze/default/document-open-folder.svg")));
     selectDriversDirB->setAttribute(Qt::WA_LayoutUsesWidgetRect);
 
-    #ifdef Q_OS_OSX
+#ifdef Q_OS_OSX
     connect(kcfg_indiServerIsInternal, SIGNAL(clicked()), this, SLOT(toggleINDIInternal()));
     kcfg_indiServerIsInternal->setToolTip(i18n("Internal or External INDI Server?"));
     connect(kcfg_indiDriversAreInternal, SIGNAL(clicked()), this, SLOT(toggleDriversInternal()));
     kcfg_indiDriversAreInternal->setToolTip(i18n("Internal or External INDI Drivers?"));
 
-    if(Options::indiServerIsInternal())
+    if (Options::indiServerIsInternal())
         kcfg_indiServer->setEnabled(false);
-    if(Options::indiDriversAreInternal())
+    if (Options::indiDriversAreInternal())
         kcfg_indiDriversDir->setEnabled(false);
 
-    #else
+#else
     kcfg_indiServerIsInternal->setVisible(false);
     kcfg_indiDriversAreInternal->setVisible(false);
-    #endif
+#endif
 
     connect(selectFITSDirB, SIGNAL(clicked()), this, SLOT(saveFITSDirectory()));
-    connect(selectDriversDirB, SIGNAL(clicked()), this, SLOT(saveDriversDirectory()));    
+    connect(selectDriversDirB, SIGNAL(clicked()), this, SLOT(saveDriversDirectory()));
     connect(showLogsB, SIGNAL(clicked()), this, SLOT(slotShowLogFiles()));
     connect(kcfg_indiServer, SIGNAL(editingFinished()), this, SLOT(verifyINDIServer()));
 
-    #ifdef Q_OS_WIN
+#ifdef Q_OS_WIN
     kcfg_indiServer->setEnabled(false);
-    #endif
+#endif
 }
 
-
-OpsINDI::~OpsINDI() {}
+OpsINDI::~OpsINDI()
+{
+}
 
 void OpsINDI::toggleINDIInternal()
 {
     kcfg_indiServer->setEnabled(!kcfg_indiServerIsInternal->isChecked());
-    if(kcfg_indiServerIsInternal->isChecked())
+    if (kcfg_indiServerIsInternal->isChecked())
         kcfg_indiServer->setText("*Internal INDI Server*");
     else
         kcfg_indiServer->setText(KSUtils::getDefaultPath("indiServer"));
@@ -80,15 +82,18 @@ void OpsINDI::toggleINDIInternal()
 void OpsINDI::toggleDriversInternal()
 {
     kcfg_indiDriversDir->setEnabled(!kcfg_indiDriversAreInternal->isChecked());
-    if(kcfg_indiDriversAreInternal->isChecked())
+    if (kcfg_indiDriversAreInternal->isChecked())
         kcfg_indiDriversDir->setText("*Internal INDI Drivers*");
     else
         kcfg_indiDriversDir->setText(KSUtils::getDefaultPath("indiDriversDir"));
+
+    KSNotification::info(i18n("You need to restart KStars for this change to take effect."));
 }
 
 void OpsINDI::saveFITSDirectory()
 {
-    QString dir = QFileDialog::getExistingDirectory(KStars::Instance(), i18n("FITS Default Directory"), kcfg_fitsDir->text());
+    QString dir =
+        QFileDialog::getExistingDirectory(KStars::Instance(), i18n("FITS Default Directory"), kcfg_fitsDir->text());
 
     if (!dir.isEmpty())
         kcfg_fitsDir->setText(dir);
@@ -96,10 +101,14 @@ void OpsINDI::saveFITSDirectory()
 
 void OpsINDI::saveDriversDirectory()
 {
-    QString dir = QFileDialog::getExistingDirectory(KStars::Instance(), i18n("INDI Drivers Directory"), kcfg_indiDriversDir->text());
+    QString dir = QFileDialog::getExistingDirectory(KStars::Instance(), i18n("INDI Drivers Directory"),
+                                                    kcfg_indiDriversDir->text());
 
     if (!dir.isEmpty())
+    {
         kcfg_indiDriversDir->setText(dir);
+        KSNotification::info(i18n("You need to restart KStars for this change to take effect."));
+    }
 }
 
 void OpsINDI::slotShowLogFiles()
@@ -122,4 +131,3 @@ void OpsINDI::verifyINDIServer()
 
     KSNotification::error(i18n("%1 is not a valid INDI server binary!", kcfg_indiServer->text()));
 }
-
