@@ -13,8 +13,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef LABELNODE_H_
-#define LABELNODE_H_
+
+#pragma once
 
 #include "skynode.h"
 #include "../labelsitem.h"
@@ -26,21 +26,23 @@ class QSGSimpleTextureNode;
 class SkyLabeler;
 class RootNode;
 
-    /** @class LabelNode
-     *
-     *@short A SkyNode derived class used for displaying labels
-     *@author Artem Fedoskin
-     *@version 1.0
-     */
+/**
+ * @class LabelNode
+ *
+ * @short A SkyNode derived class used for displaying labels
+ * @author Artem Fedoskin
+ * @version 1.0
+ */
 
-class LabelNode : public SkyNode  {
-public:
+class LabelNode : public SkyNode
+{
+  public:
     /**
      * @short Constructor. Use name of skyObject as a text
      * @param skyObject - target object, for which this label is created.
      * @param type - type of label (corresponds to type of SkyObject)
      */
-    LabelNode(SkyObject * skyObject, LabelsItem::label_t type);
+    LabelNode(SkyObject *skyObject, LabelsItem::label_t type);
 
     /**
      * @short Constructor. Use string parameter name as a text
@@ -94,10 +96,11 @@ public:
      * @short Update position of label according to labelPos and recreate texture if label's size
      * depends on zoom level
      */
-    void update();
+    virtual void update() override;
 
     QPointF labelPos;
-private:
+
+  private:
     QString m_name;
     QSGSimpleTextureNode *m_textTexture;
     QSize m_textSize;
@@ -108,7 +111,3 @@ private:
     QString m_schemeColor;
     QColor m_color;
 };
-
-#endif
-
-
