@@ -22,7 +22,6 @@
 
 #include "projector.h"
 
-
 /**
  * @class AzimuthalEquidistantProjector
  *
@@ -31,13 +30,12 @@
  */
 class AzimuthalEquidistantProjector : public Projector
 {
-
-public:
-    explicit AzimuthalEquidistantProjector(const ViewParams& p);
-    virtual Projection type() const;
-    virtual double radius() const;
-    virtual double projectionK(double x) const;
-    virtual double projectionL(double x) const;
+  public:
+    explicit AzimuthalEquidistantProjector(const ViewParams &p);
+    Projection type() const Q_DECL_OVERRIDE;
+    double radius() const Q_DECL_OVERRIDE;
+    double projectionK(double x) const Q_DECL_OVERRIDE;
+    double projectionL(double x) const Q_DECL_OVERRIDE;
 };
 
 #endif // AZIMUTHALEQUIDISTANTPROJECTOR_H
