@@ -15,13 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef ConstellationArtComponent_H
-#define ConstellationArtComponent_H
-
-#include <QImage>
-#include <QSqlDatabase>
-
-#include "Options.h"
+#pragma once
 
 #include "skycomponent.h"
 
@@ -37,12 +31,11 @@ class CultureList;
  */
 class ConstellationArtComponent : public SkyComponent
 {
-public:
+  public:
+    /** Constructor */
+    explicit ConstellationArtComponent(SkyComposite *, CultureList *cultures);
 
-    /** Constructor*/
-    explicit ConstellationArtComponent ( SkyComposite*, CultureList* cultures );
-
-    /** Destructor*/
+    /** Destructor */
     ~ConstellationArtComponent();
 
     /**
@@ -59,19 +52,14 @@ public:
      */
     void deleteData();
 
-    /**
-     * @short Shows the details of the constellations
-     * selected skyculture
-     */
+    /** @short Shows the details of the constellations selected skyculture */
     void showList();
 
-    virtual void draw( SkyPainter *skyp );
+    void draw(SkyPainter *skyp) Q_DECL_OVERRIDE;
 
-    QList<ConstellationsArt*> m_ConstList;
+    QList<ConstellationsArt *> m_ConstList;
 
-private:
+  private:
     QString cultureName;
     int records;
 };
-
-#endif // ConstellationArtComponent_H
