@@ -27,28 +27,28 @@ class QTextStream;
   *@class modCalcEquinox
   *@author Jason Harris
   */
-class modCalcEquinox : public QFrame, public Ui::modCalcEquinox  {
-
+class modCalcEquinox : public QFrame, public Ui::modCalcEquinox
+{
     Q_OBJECT
 
-public:
+  public:
     modCalcEquinox(QWidget *p);
     ~modCalcEquinox();
 
     KStarsDateTime dSpring, dSummer, dAutumn, dWinter;
     double dmonth(int imonth);
 
-private slots:
+  private slots:
     void slotCompute();
     void slotCheckFiles();
     void slotRunBatch();
     void slotViewBatch();
 
-private:
-    void processLines( QTextStream &istream );
+  private:
+    void processLines(QTextStream &istream);
     void addDateAxes();
-    KStarsDateTime findEquinox( int year, bool Spring, KPlotObject *po );
-    KStarsDateTime findSolstice( int year, bool Summer );
+    KStarsDateTime findEquinox(int year, bool Spring, KPlotObject *po);
+    KStarsDateTime findSolstice(int year, bool Summer);
     double DMonth[12];
 };
 
