@@ -29,45 +29,44 @@ class KSHelpLabel : public QLabel
     Q_PROPERTY(QString anchor READ anchor WRITE setAnchor)
     Q_PROPERTY(QString text READ text WRITE setText)
 
-public:
+  public:
     /**
-     * Constructor. Creates clear label
-     */
+         * Constructor. Creates clear label
+         */
     explicit KSHelpLabel(QWidget *parent = 0);
 
     /**
-     * Constructor. Creates label with a text and help anchor.
-     * @param text Text of the label
-     * @param anchor Name of the section in the AstroInfo project (without 'ai-')
-     */
-    KSHelpLabel(const QString& text, const QString& anchor,
-                QWidget *parent = 0);
+         * Constructor. Creates label with a text and help anchor.
+         * @param text Text of the label
+         * @param anchor Name of the section in the AstroInfo project (without 'ai-')
+         */
+    KSHelpLabel(const QString &text, const QString &anchor, QWidget *parent = 0);
 
     QString text() const { return m_cleanText; }
-    void setText(const QString& text);
+    void setText(const QString &text);
 
-    void setAnchor(const QString& anchor);
+    void setAnchor(const QString &anchor);
     QString anchor() const { return m_anchor; }
 
-private slots:
+  private slots:
     /** Open AstroInfo definition of the terms
-     * @param term jargon term */
-    void slotShowDefinition(const QString & term);
+         * @param term jargon term */
+    void slotShowDefinition(const QString &term);
 
-private:
+  private:
     /**
-     * Updates text with the new anchor
-     */
+         * Updates text with the new anchor
+         */
     void updateText();
 
     /**
-     * Anchor in AstroInfo project
-     */
+         * Anchor in AstroInfo project
+         */
     QString m_anchor;
 
     /**
-     * String without markup
-     */
+         * String without markup
+         */
     QString m_cleanText;
 };
 
